-- AEROSOFT AIRBUS
-- Module version 4.4
-- Oct 2016

-- ## System functions ###############

function Timer ()
    -- check AP2 status
    if ipc.readLvar('AB_AP_LOC2') == 0 and
        ipc.readLvar('AB_AP_AP2') == 1 and
        ipc.readLvar('AB_AP_AP1') == 1 then
        ipc.writeLvar(AB_AP_AP2, 0)
    end
    -- set display information
    if _MCP2() then
        if ipc.get("DSPmode") == 1 then
            -- show autopilot info
            AB_AP_INFO ()
        else
            -- show flaps/gears info
            AB_FLIGHT_INFO ()
        end
    elseif _MCP2a() then
        if ipc.get("DSPmode") == 1 then
            -- keep flag until all MODEs reset
            local info = Modes()
            if info ~= "M111" then
                AB_MODE = true
            else
                AB_MODE = false
            end
            -- show autopilot info
            AB_AP_INFO ()
        else
            -- show flaps/gears info
            AB_FLIGHT_INFO ()
        end
    else  -- Display for MCP1 Users
        -- Display Autopilot
        DispAutopilot_MCP1 ()
        -- Display Gearstatus
        DispGear_MCP1 ()
        -- Display Flapstatus
        DispFlaps_MCP1 ()
    end
    -- set timer for MCDU Key Input Reversion
    if ipc.readLvar("L:MCDU_KBD") == 1 and AB_MCDU_KeyFlag == false then
        MCDU_KEYB_on()
        sound.play("modechange")
    else
        --AB_MCDU_KeyFlag = false
    end
    -- handle timer for MCDU Key Input Reversion
    if ipc.elapsedtime() - ipc.get("MCDU") > AB_MCDU_KeyTimer
        and AB_MCDU_KeyFlag then
        MCDU_KEYB_off()
        sound.play("modechange")
    end
end

----------------------------------------------------------

-- display AP mode information
function AB_AP_INFO ()
    if _MCP2() then
        -- FD
        if ipc.readLvar('AB_MPL_FD') == 0 then
            DspFD(0)
        else
            DspFD(1)
        end
        -- ATHR
        if ipc.readLvar('AB_AP_ATHR') == 0 then
            DspAT(0)
        else
            DspAT(1)
        end
        -- LNAV
        if ipc.readLvar('AB_AP_HDGmode_setDisp') == 1 then
            DspLNAV_on ()
        else
            DspLNAV_off ()
            DspHDGmode(AB_HDGmode_Dot())
        end
        -- VNAV
        if ipc.readLvar('AP_AP_ALT_Mode') == 1 then
            DspVNAV_on ()
            DspALTmode(true)
        else
            DspVNAV_off ()
            DspALTmode(false)
        end
        local Var, str1, str2
        -- A/THR
        Var = ipc.readLvar('AB_AP_ATHR')
        DspAT(Var)
        -- AP1
        Var = ipc.readLvar('AB_AP_AP1')
        if Var == 1 then
            str1 = ' 1AP'
        else
            str1 = ' -AP'
        end
        -- AP2
        Var = ipc.readLvar('AB_AP_AP2')
        if Var == 1 then
            str1 = str1 .. '2 '
        else
            str1 = str1 .. '- '
        end
        -- ILS
        Var = ipc.readLvar('AB_MPL_ILS')
        if Var == 1 then
            str2 = ' ILS '
        else
            str2 = '     '
        end
        -- LOC or APPR
        if (ipc.readLvar('AB_AP_LOC') == 1) then
            str2 = str2 .. 'LOC'
        elseif (ipc.readLvar('AB_AP_LOC2') == 1) then
            str2 = str2 .. 'APR'
        end
        FLIGHT_INFO1 = str1
        FLIGHT_INFO2 = str2
    elseif _MCP2a() then -- Airbus FCU
        local Var
        -- ILS
        Var = ipc.readLvar('AB_MPL_ILS')
        DspILS(Var)
        -- APs 1 & 2
        DspAPs(ipc.readLvar('AB_AP_AP1'), ipc.readLvar('AB_AP_AP2'))
        -- A/THR
        Var = ipc.readLvar('AB_AP_ATHR')
        DspAT(Var)
        -- LOC
        Var = ipc.readLvar('AB_AP_LOC')
        DspLOC(Var)
        -- APPR
        Var = ipc.readLvar('AB_AP_LOC2')
        if not AB_MODE then
            DspAPPR(Var)
        end
        -- reset flight information for Airbus MCP2a display
        FLIGHT_INFO1 = ""
        FLIGHT_INFO2 = ""
    end
    -- SPD/MACH labels
    DspSPDtxt(ipc.readLvar('AB_AP_SPDMACH'))
    -- HDG/TRK labels
    DspHDGtxt(ipc.readLvar('AB_AP_HDGTRK'))
    -- ALT labels
    DspALTtxt()
    -- ALT/VVS DspE to avoid cursor flicker
    AB_DspE()
    -- AP VALUES --
    AB_DspSPD ()
    AB_DspHDG ()
    AB_DspALT ()
    AB_DspVVS ()
end

-----------------------------------------------------------

-- Display Flight Information
function AB_FLIGHT_INFO ()
local APUState, GndPwr, Cones, Chocks, GndConn
local PaxBoard, PaxMax, PaxAct, PaxPzt
local CargoBoard, CargoMax, CargoAct, CargoPzt
local FuelBoard, FuelMax, FuelAct, FuelPzt

    APUstate = round(ipc.readLvar("APU_PCT_RPM"))
    GndPwr = ipc.readLvar('AB_OVH_ELECEXT_AVAIL2')
    Cones = ipc.readLvar('Cones')
    Chocks = ipc.readLvar('Wheelchocks')
    GndConn = GndPwr + Cones + Chocks

    -- *** NOTE - Lvars misspelt but correct (Dec 14)

    PaxBoard = ipc.readLvar('AB_MCUD2_LD_STS_PAX') -- ***
    PaxMax = ipc.readLvar('AB_MCDU2_LS_PAX')
    PaxAct = ipc.readLvar('MCDU2_Loaded_Pax')

    CargoBoard = ipc.readLvar('AB_MCUD2_LD_STS_CAR') -- ***
    CargoMax = ipc.readLvar('AB_MCDU2_LS_CAR_KG')
    CargoAct = ipc.readLvar('MCDU2_Loaded_Cargo')

    FuelBoard = ipc.readLvar('AB_MCUD2_LD_STS_FUEL') -- ***
    FuelMax = ipc.readLvar('AB_MCDU2_LS_FUEL_KG')
    FuelAct = ipc.readLvar('MCDU2_Load_act_Fuel')

    -- calculate percentage boarded
    if PaxMax > 0 then
        PaxPzt = round((PaxAct/PaxMax)*100)
    else
        PaxPzt = 0
    end
    if CargoMax > 0 then
        CargoPzt = round((CargoAct/CargoMax)*100)
    else
        CargoPzt = 0
    end
    if FuelMax > 0 then
        FuelPzt = round((FuelAct/FuelMax)*100)
    else
        FuelPzt = 0
    end

    -- check APU runnng state
    if APUstate < 1 or APUstate > 99 then
        if _MCP2a() and Airbus then
            -- form output text
            PaxTxt = "Pax ".. PaxPzt .. "%"
            CargoTxt = "Cargo ".. CargoPzt .. "%"
            FuelTxt = "Fuel ".. FuelPzt .. "%"

            FLIGHT_INFO2 = ''
            if FuelBoard == 1 then
                FLIGHT_INFO1 = FuelTxt
            elseif PaxBoard == 1 then
                FLIGHT_INFO1 = PaxTxt
            elseif CargoBoard == 1 then
            FLIGHT_INFO1 = CargoTxt
            elseif GndConn > 0 then
                FLIGHT_INFO1 = "Gnd"
                FLIGHT_INFO2 = "Cons"
            else
                AB_ExtPwr_show()
            end
        else -- MCP1 or MCP2
            _logg('[awg] Flt Info MCP1/2')
            FLIGHT_INFO1 = ''
            FLIGHT_INFO2 = ''
            PaxTxt = "Pax  ".. PaxPzt .. "%"
            CargoTxt = "Crgo ".. CargoPzt .. "%"
            FuelTxt = "Fuel ".. FuelPzt .. "%"
            if (FuelBoard == 1
                and PaxBoard == 1
                and CargoBoard == 1) then
                FLIGHT_INFO1 = PaxTxt
                FLIGHT_INFO2 = FuelTxt
            elseif (FuelBoard == 1
                and PaxBoard ~= 1
                and CargoBoard ~= 1) then
                FLIGHT_INFO1 = FuelTxt
                FLIGHT_INFO2 = "        "
            elseif (FuelBoard ~= 1
                and PaxBoard == 1
                and CargoBoard ~= 1) then
                FLIGHT_INFO1 = PaxTxt
                FLIGHT_INFO2 = "        "
            elseif (FuelBoard ~=1
                and PaxBoard ~= 1
                and CargoBoard == 1) then
                FLIGHT_INFO1 = CargoTxt
                FLIGHT_INFO2 = "        "
            elseif (FuelBoard == 1
                and PaxBoard == 1
                and CargoBoard ~= 1) then
                FLIGHT_INFO1 = PaxTxt
                FLIGHT_INFO2 = FuelTxt
            elseif (FuelBoard == 1
                and PaxBoard ~= 1
                and CargoBoard == 1) then
                FLIGHT_INOF1 = CargoTxt
                FLIGHT_INFO2 = FuelTxt
            elseif (FuelBoard ~=1
                and PaxBoard == 1
                and CargoBoard == 1) then
                FLIGHT_INFO1 = PaxTxt
                FLIGHT_INFO2 = CargoTxt
            elseif GndConn > 0 then
                AB_ExtPwr_show()
            else
                ECAM_modes_show()
            end
        end
--[[    _logg('[awg] AB F:' .. FuelBoard .. '/'
        .. FuelPzt .. '% =' .. FuelTxt
        .. '/P:' .. PaxBoard .. '/'
        .. PaxPzt .. '% =' .. PaxTxt
        .. '/C:' .. CargoBoard .. '/'
        .. CargoPzt .. '% =' .. CargoTxt
        .. '/Grd=' .. GndConn)
--]]
    else
        FLIGHT_INFO1 = ""
        FLIGHT_INFO2 = ""
    end
end

    --- Ground Conn
function AB_ExtPwr_show ()
    ExtPwr = ipc.readLvar('AB_OVH_ELECEXT_AVAIL2') + ipc.readLvar('AB_OVH_ELECEXT')
    Cones = ipc.readLvar('Cones')
    Chocks = ipc.readLvar('Wheelchocks')
    if ExtPwr >= 1 and Cones == 1 and Chocks == 1 then
        ExtPwrTxtLong1 = "GPU|Chks"
        ExtPwrTxtLong2 = "Cones   "
        ExtPwrTxtShort1 = "Ext "
        ExtPwrTxtShort2 = "Pwr "
    elseif ExtPwr >= 1 and Cones == 1 and Chocks == 0 then
        ExtPwrTxtLong1 = "GPU     "
        ExtPwrTxtLong2 = "Cones   "
        ExtPwrTxtShort1 = "Ext "
        ExtPwrTxtShort2 = "Pwr "
    elseif ExtPwr >= 1 and Cones == 0 and Chocks == 0 then
        ExtPwrTxtLong1 = "GPU     "
        ExtPwrTxtLong2 = "avail   "
        ExtPwrTxtShort1 = "Ext "
        ExtPwrTxtShort2 = "Pwr "
    elseif ExtPwr >= 0 and Cones == 1 and Chocks == 1 then
        ExtPwrTxtLong1 = "Cones   "
        ExtPwrTxtLong2 = "Chocks  "
        ExtPwrTxtShort1 = "Cons"
        ExtPwrTxtShort2 = "Chks"
    elseif ExtPwr == 0 and Cones == 0 and Chocks == 1 then
        ExtPwrTxtLong1 = "Wheel   "
        ExtPwrTxtLong2 = "Chocks  "
        ExtPwrTxtShort1 = "Chks"
        ExtPwrTxtShort2 = "    "
    elseif ExtPwr >= 1 and Cones == 0 and Chocks == 1 then
        ExtPwrTxtLong1 = "GPU     "
        ExtPwrTxtLong2 = "Chocks  "
        ExtPwrTxtShort1 = "Ext "
        ExtPwrTxtShort2 = "Pwr "
    elseif ExtPwr == 0 and Cones == 1 and Chocks == 0 then
        ExtPwrTxtLong1 = "Cones   "
        ExtPwrTxtLong2 = "        "
        ExtPwrTxtShort1 = "Cone"
        ExtPwrTxtShort2 = "    "
    else
        ExtPwrTxtLong1 = "        "
        ExtPwrTxtLong2 = "        "
        ExtPwrTxtShort1 = "    "
        ExtPwrTxtShort2 = "    "
    end
    if (_MCP2a() and Airbus) or _MCP1() then
        FLIGHT_INFO1 = ExtPwrTxtShort1
        FLIGHT_INFO2 = ExtPwrTxtShort2
    else -- MCP2
        FLIGHT_INFO1 = ExtPwrTxtLong1
        FLIGHT_INFO2 = ExtPwrTxtLong2
    end
end

-- ## System show ###############

function Throttle_detends_show ()
    -- throttle detends
    ENG1_THRdet = ipc.readLvar('ThrottleDetend_CheckL')
    ENG2_THRdet = ipc.readLvar('ThrottleDetend_CheckR')
    ENG_THRdet = (ENG1_THRdet + ENG2_THRdet)/2
    if ENG_THRdet == 0 then
        DetTxt1 = "IDLE"
    elseif ENG_THRdet == 20 or ENG_THRdet == 25 then
        DetTxt1 = "CLB"
    elseif ENG_THRdet == 75 then
        DetTxt1 = "MCT"
    elseif ENG_THRdet == 100 then
        DetTxt1 = "TOGA"
    end
    if _MCP2() then
        FLIGHT_INFO1 = "Throttle"
        FLIGHT_INFO2 = DetTxt1
    else
        FLIGHT_INFO1 = "THR"
        FLIGHT_INFO2 = DetTxt1
    end
end

-- ## Display functions ###############

function DispAutopilot_MCP1 ()

    ILS_cur = ipc.readLvar("L:AB_MPL_ILS")
    LOC_cur = ipc.readLvar("L:AB_AP_LOC")
    AP1_cur = ipc.readLvar("L:AB_AP_AP1")
    AP2_cur = ipc.readLvar("L:AB_AP_AP2")
    ATT_cur = ipc.readLvar("L:AB_AP_ATHR")
    APP_cur = ipc.readLvar("L:AB_AP_LOC2")
    FD_cur  = ipc.readLvar("L:AB_MPL_FD")

    APUbleed_cur    = ipc.readLvar("L:AB_OVH_PNEUBLEEDAPU")
    MASTERcaut_cur  = ipc.readLvar("L:AB_MPL_Master_Warning_Light_state")
    MASTERwarn_cur  = ipc.readLvar("L:AB_MPL_Master_Warning_Light_state")

    SPDmode_cur = ipc.readLvar("L:AB_AP_SPDmode_set")
    HDGmode_cur = ipc.readLvar("L:AB_AP_HDGmode_set")
    -- VSmode_cur  = ipc.readSB(0x5634)

    QNH_cur = ipc.readSW(0x0330) / 16

    -- QNH changed
    if QNH_cur ~= QNH_pre then
        QNH_pre = QNH_cur
        if round(QNH_cur, 0) == 1013 then
            DspShow ('BARO', ' STD')
        else
            DspShow('BARO', QNH_cur)
        end
    end

    -- Important LED change
        -- MASTER Caution
    if MASTERcaut_cur ~= MASTERcaut_pre then
        MASTERcaut_pre = MASTERcaut_cur
        if MASTERcaut_cur == 1 then
            FLIGHT_INFO1 = 'MSTR'
            FLIGHT_INFO2 = 'CAUT'
        else
            APchange = true
        end
    end

        -- MASTER Warning
    if MASTERwarn_cur ~= MASTERwarn_pre then
        MASTERwarn_pre = MASTERwarn_cur
        if MASTERwarn_cur == 1 then
            FLIGHT_INFO1 = 'MSTR'
            FLIGHT_INFO2 = 'WARN'
        else
            APchange = true
        end
    end
        -- APU Bleed LED on/off
    if APUbleed_cur ~= APUbleed_pre then
        APUbleed_pre = APUbleed_cur
        if APUbleed_cur == 1 then
            DspShow("APUb",">>on")
        else
            DspShow("APUb",">off")
        end
    end

    -- Selected / Managed Display
    if SPDmode_cur ~= SPDmode_pre then
        SPDmode_pre = SPDmode_cur
        if SPDmode_cur == 1 then
            val = '---'
    	else
            val = 'sel'
        end
        DspShow ("SPD", val)
    end

    if HDGmode_cur ~= HDGmode_pre then
        HDGmode_pre = HDGmode_cur
        if HDGmode_cur == 1 then
            val = '---'
    	else
            val = 'sel'
        end
        DspShow ("HDG", val)
    end

    if VSmode_cur ~= VSmode_pre then
        VSmode_pre = VSmode_cur
        if VSmode_cur == 1 then
            val = '---'
    	else
            val = 'sel'
        end
        DspShow ("VS", val)
    end

    -- Autopilot Display
    -- AP1
	if AP1_cur ~= AP1_pre then
        AP1_pre = AP1_cur
        APchange = true
        if AP1_cur == 1 then
            D11 = "1"
        else
            D11 = "_"
        end
	end

    -- AP2
	if AP2_cur ~= AP2_pre then
        AP2_pre = AP2_cur
        APchange = true
        if AP2_cur == 1 then
            D12 = "2"
        else
            D12 = "_"
        end
	end

    -- APPR mode
	if APP_cur ~= APP_pre then
        APP_pre = APP_cur
        APchange = true
        if APP_cur == 1 then
            D14 = "A"
        else
            D14 = "_"
        end
	end
    -- LOC mode
	if LOC_cur ~= LOC_pre then
        LOC_pre = LOC_cur
        APchange = true
        if LOC_cur == 1 then
            D14 = "L"
        else
            D14 = D14
        end
	end

    -- FD
	if FD_cur ~= FD_pre then
        FD_pre = FD_cur
        APchange = true
        if FD_cur == 1 then
            D21 = "F"
        else
            D21 = "_"
        end
	end

    -- ILS
	if ILS_cur ~= ILS_pre then
        ILS_pre = ILS_cur
        APchange = true
        if ILS_cur == 1 then
            D22 = "I"
        else
            D22 = "_"
        end
	end

    -- ATHR
	if ATT_cur ~= ATT_pre then
        ATT_pre = ATT_cur
        APchange = true
        if ATT_cur == 1 then
            D24 = "T"
        else
            D24 = "_"
        end
	end

    -- form 2 lines of flight info display
    if APchange == true then
        APchange = false
        FLIGHT_INFO1 = D11 .. D12 .. ' ' .. D14
        FLIGHT_INFO2 = D21 .. D22 .. ' ' .. D24
    end
end

function DispGear_MCP1 ()
    GNOSE_cur = ipc.readSD(0x0BEC)
    GLEFT_cur = ipc.readSD(0x0BF4)
    GRIGHT_cur = ipc.readSD(0x0BF0)

    if GNOSE_cur ~= GNOSE_pre then
        GNOSE_pre = GNOSE_cur
        GEARchange = true

        if GNOSE_cur == 16383 then
            GNOSE = ' oo'
        elseif GNOSE_cur == 0 then
            GNOSE = ' -- '
        else
            GNOSE = ' ** '
        end
    end

    if GLEFT_cur ~= GLEFT_pre then
        GLEFT_pre = GLEFT_cur
        GEARchange = true

        if GLEFT_cur == 16383 then
            GLEFT = 'o##'
        elseif GLEFT_cur == 0 then
            GLEFT = '-##'
        else
            GLEFT = '*##'
        end
    end

    if GRIGHT_cur ~= GRIGHT_pre then
        GRIGHT_pre = GRIGHT_cur
        GEARchange = true

        if GRIGHT_cur == 16383 then
            GRIGHT = 'o'
        elseif GRIGHT_cur == 0 then
            GRIGHT = '-'
        else
            GRIGHT = '*'
        end
    end

    if GEARchange == true then
        GEARchange = false
        FLIGHT_INFO1 = GNOSE
        FLIGHT_INFO2 = GLEFT .. GRIGHT
    else
        APchange = true
    end
end

function DispFlaps_MCP1 ()

    FLAP_cur = ipc.readSD(0x0BDC)

    if FLAP_pre ~= FLAP_cur then
        FLAP_pre = FLAP_cur

        if FLAP_cur == 0 then
            FLAP = '----'
            FLAPchange=true
        elseif FLAP_cur == 4096 or FLAP_cur == 6553 then
            FLAP = '1---'
            FLAPchange=true
        elseif FLAP_cur == 8192 then
            FLAP = '-2--'
            FLAPchange=true
        elseif FLAP_cur == 12287 then
            FLAP = '--3-'
            FLAPchange=true
        else
            FLAP = '---4'
            FLAPchange=true
        end
    end

    if FLAPchange == true then
        FLAPchange=false
        DspShow('FLAP', FLAP)
    else
        APchange = true
    end
end

function ECAM_modes_show ()
    -- ECAM modes
    EcamVar = ipc.readLvar('ECAM_Mode')
--    _log("ECAM Mode = " .. EcamVar)
    if EcamVar == 1 then EcamTxt = "ENG "
    elseif EcamVar == 2 then EcamTxt = "BLED"
    elseif EcamVar == 3 then EcamTxt = "PRES"
    elseif EcamVar == 4 then EcamTxt = "ELEC"
    elseif EcamVar == 5 then EcamTxt = "HYD "
    elseif EcamVar == 6 then EcamTxt = "FUEL"
    elseif EcamVar == 7 then EcamTxt = "APU "
    elseif EcamVar == 8 then EcamTxt = "COND"
    elseif EcamVar == 9 then EcamTxt = "DOOR"
    elseif EcamVar == 10 then EcamTxt = "WHEL"
    elseif EcamVar == 11 then EcamTxt = "FCTL"
    elseif EcamVar == 12 then EcamTxt = "ALL "
    elseif EcamVar == 13 then EcamTxt = "SYS "
    elseif EcamVar == 14 then EcamTxt = "CRSE"
    else EcamTxt = "none"
    end

    -- Flap state
    FlapState = ipc.readLvar('ASC_Flaps_index')
    if FlapState == 0 then
        FlapStatetxt = "up"
    elseif FlapState == 1 then
        FlapStatetxt = " 1"
    elseif FlapState == 2 then
        FlapStatetxt = " 2"
    elseif FlapState == 3 then
        FlapStatetxt = " 3"
    elseif FlapState == 4 then
        FlapStatetxt = "dn"
    end

    if _MCP2() then
        APUstate = round(ipc.readLvar("APU_PCT_RPM"))
        if APUstate < 1 then
            FLIGHT_INFO1 = "FL ECAM"
            FLIGHT_INFO2 = FlapStatetxt .. " " .. EcamTxt
        elseif APUstate > 1 then
            FLIGHT_INFO1 = "FL APU"
            FLIGHT_INFO2 = FlapStatetxt .. " " .. APUstate .. "%  "
        end
    else
        DspShow ("ECAM", EcamTxt)
    end
end

function AB_DspSPD()
    AB_spd = ipc.readLvar("AB_AP_SPEED_Select")
    AB_mach = ipc.readLvar("AB_AP_MACH_Select")
    SPDTimeVar = ipc.readLvar("FCU_Managed_SPDdisp_override")
    SPDModeSet = ipc.readLvar("AB_AP_SPDmode_set")
    SpdMachVar = ipc.readLvar("AB_AP_SPDMACH")
    local strVal
    if (SPDModeSet == 1 and SPDTimeVar == 0) then
        strVal = '---'
        if _MCP2a() then
            strVal = '---' .. string.char(7)
        else
            strVal = '---*'
        end
        DspSPDs(strVal, true)
    elseif not _MCP1() then
        if SpdMachVar == 0 then
            AB_spdMach = AB_spd
            DspSPD(AB_spdMach)
            DspSPDs('\\\\\\ ')
            if AB_SPDmode_Dot() then
                if _MCP2a() then
                    DspSPDmode(true)
                else
                    DspSPD_AP_on()
                end
            else
                if _MCP2a() then
                    DspSPDmode(false)
                else
                    DspSPD_AP_off()
                end
            end
        else -- MACH
            AB_spdMach = AB_mach*100+0.5
            DspSPDs("0." .. AB_spdMach)
        end
    end
end

function AB_DspHDG ()
    AB_hdg = ipc.readLvar("AB_AP_HDG_Select")
    AB_trk = ipc.readLvar("Autopilot_TRK_set")
    AB_hdgtrk = ipc.readLvar("AB_AP_HDGTRK")
    AB_drift = ipc.readLvar("WindDriftVal")
    HDGmodeSet = ipc.readLvar("AB_AP_HDGmode_setDisp")
    HDGoverride = ipc.readLvar("FCU_Managed_HDGdisp_override")
    if HDGmodeSet >= 0 and HDGoverride == 0
    then
        if _MCP2a() then
            DspHDGs("---" .. string.char(7))
        else
            DspHDGs("---*")
        end
        DspHDGmode(true)
    else
        if AB_hdgtrk == 0 then
            AB_hdg = round(AB_hdg)
        else -- calculate track
            AB_hdg = round(AB_trk)
        end
        DspHDG(AB_hdg)
        DspHDGmode(AB_HDGmode_Dot())
    end
end

function AB_DspALT ()
    AB_alt = ipc.readLvar("AB_AP_ALT_Select")
    if _MCP1() then return end
    DspALT(AB_alt/100)
    DspALTmode()
end

function AB_DspVVS ()
local VS_alt
    KNOBALT = ipc.readLvar("AB_AP_KNOBALT")
    VSOverride = ipc.readLvar("FCU_Managed_VSdisp_override")
    if KNOBALT == 0 and VSOverride == 0 then
        if _MCP2a() then
            DspVVSs("----")
            AB_VVS_Sign = '-'
        else
            DspVVS_AP_on()
            DspVVSs("----", true)
        end
    else
        DspVVS_AP_off()
        if ipc.readLvar("AB_AP_HDGTRK") == 0 then
            VS_alt = ipc.readLvar("AB_AP_VS_Select2")
            DspVVS((VS_alt) * 1.0)
            if VS_alt >= 0 then
                AB_VVS_Sign = '+'
            else
                AB_VVS_Sign = '-'
            end
        else  -- display FPA
            VS_alt = ipc.readLvar("AB_AP_FPA_Select2")
            DspFPA((VS_alt) * 1.0)
            AB_VVS_Sign = ' '
        end
    end
end

-- function to stop DspE field flashing
function AB_DspE(val)
    if _MCP1() or _MCP2() then return end
    if val == nil then
        val = "0" .. AB_ALT_Dot .. "\\" .. AB_VVS_Sign
    end
    DspE(val, false)
end

function APU_Ready_show ()
    ApuGen = ipc.readLvar("APU_avail")
    if ApuGen == 1 then
    	DspShow ("APU", "rdy")
     	ipc.sleep(4000)
    end
end

-- AP mode dots
function AB_SPDmode_Dot ()
    SPD_mode_set = ipc.readLvar('AB_AP_SPDmode_set')
    if SPD_mode_set == 1 then
        return true
    else
        return false
    end
end

function AB_HDGmode_Dot ()
    HDG_mode_set = ipc.readLvar('AB_AP_HDGmode_setDisp')
    if HDG_mode_set == 1 then
        return true
    else
        return false
    end
end

function AB_ALTmode_Dot ()
    ALT_mode = ipc.readLvar('L:AP_AP_ALT_Mode')
    if ALT_mode == 1 then
        return true
    else
        return false
    end
end

function AB_DspAP1_on()
    DspAP1(true)
end

function AB_DspAP1_off()
    DspAP1(false)
end

function AB_DspAP2_on()
    DspAP2(true)
end

function AB_DspAP2_off()
    DspAP2(false)
end

function AB_DspILS_on()
    DspILS(true)
end

function AB_DspILS_off()
    DspILS(false)
end

function DspSPDtxt(i)
    if _MCP1() then return end
    -- SPD/MACH
    if _MCP2a() then
        if i == 1  then
            Dsp0('MACH')
        else
            Dsp0('SPD ')
        end
    else  -- MCP2
        if i == 1  then
            Dsp0('\\\\\\M')
            Dsp1('ACH\\')
        else
            Dsp0('\\\\\\S')
            Dsp1('PD \\')
        end
    end
end

function DspHDGtxt(i)
    if _MCP1() or _MCP2() then return end
    -- HDG/TRK
    if i == 1 then
        Dsp2('TRK ')
        DspB(' TRK')
        DspC('FPA ')
        Dsp7(' FPA')
    else
        Dsp2('HDG ')
        DspB(' HDG')
        DspC('V/S ')
        Dsp7(' V/S')
    end
end

function DspALTtxt()
    if _MCP1() or _MCP2() then return end
    -- ALT mode
    Dsp5('ALT ')
    DspD('\\\\\\0')
    --DspE('0\\\\\\')
end

function DspInfoClear()
    if _MCP1() or _MCP2() then return end
    DspILS(false)
    DspLOC(false)
    DspAT(false)
    DspAPPR(false)
    Dsp1('    ', true) -- blank ILS
    Dsp9('    ', true) -- blank LOC
    Dsp3('    ', true) -- blank APs
    Dsp4('    ', true) -- blank AT
    DspB('    ', true) -- blank HDG
    DspC('    ', true) -- blank V/S
    Dsp6('    ', true) -- blank APPR
end

function DspSPDmode (i)
	if dev == 0 then return end
    if _MCP1() then return end
    local val
    if _MCP2a() then
        if i == true then
   	        val = "\\\\\\" .. string.char(7)
        else
            val = "\\\\\\ "
        end
        Dsp8(val)
    else
        if i then
            DspSPD_AP_on()
        else
            DspSPD_AP_off()
        end
    end
end

function DspMACHmode (i)
	if dev == 0 then return end
    if not _MCP2a() then return end
    local val
    if i == true then
   	    val = string.char(7) .. "\\\\\\"
    else
        val = " \\\\\\"
    end
    Dsp9(val)
end

function DspHDGmode (i)
	if dev == 0 then return end
    if _MCP1() then return end
    local val
    if _MCP2a() then
        if i then
            val = "\\\\\\" .. string.char(7)
        else
   	        val = "\\\\\\ "
        end
        DspA(val)
    else -- MCP2
        if i then
            val = "\\\\\\*"
        else
            val = "\\\\\\ "
        end
        DspC(val)
    end
end

function DspALTmode ()
	if dev == 0 then return end
    if _MCP1() then return end
    local Dot
    local val
    Dot = ipc.readLvar('AP_AP_ALT_Mode')
    if Dot == 1 then
        if _MCP2a() then
            AB_ALT_Dot = AB_Dot
            AB_DspE()
        else
            val = "\\*\\\\"
            Dsp6(val)
        end
    else
        if _MCP2a() then
            AB_ALT_Dot = ' '
            AB_DspE()
        else
            val = "\\ \\\\"
            Dsp6(val)
        end
    end
end

function DspSPD_AP_on ()
	if dev == 0 then return end
    if not _MCP2() then return end
    if ipc.readLvar("AB_AP_MACH_Select") == 0 then
   	    ipc.sleep(20)
        com.write(dev, "DSP1\\\\*\\", 8)
    end
 end

function DspSPD_AP_off ()
	if dev == 0 then return end
    if not _MCP2() then return end
    if ipc.readLvar("AB_AP_MACH_Select") == 0 then
   	    ipc.sleep(20)
        com.write(dev, "DSP1\\\\ \\", 8)
    end
end

function DspMode_Toggle()
    if ipc.get("DSPmode") == 1 then
        DspInfoClear()
        AB_APPR = false
    end
    DSP_MODE_toggle()
end

-- ## System sounds ###############

function SmallOverheadPushButtons ()
    ipc.writeLvar("L:SmallOverheadPushButtons", 1)
end

function Button3 ()
    ipc.writeLvar("L:Button3", 1)
end

function ASC_KnobRotate ()
    ipc.writeLvar("L:ASC_KnobRotate", 1)
end

function LightSwitch ()
    ipc.writeLvar("L:LightSwitch", 1)
end

function NormalSwitch ()
    ipc.writeLvar("L:NormalSwitch", 1)
end

function AdirsKnobRotate ()
    ipc.writeLvar("L:AdirsKnobRotate", 1)
end

function ASC_MCDU_CLICK ()
    ipc.writeLvar("L:ASC_MCDU_CLICK", 1)
end


-- ## Autopilot controls #####################################

function Autopilot_AP1_check ()
    if ipc.readLvar("L:AB_AP_AP1") == 1 then
        return true
    else
        return false
    end
end

function Autopilot_AP2_check ()
    if ipc.readLvar("L:AB_AP_AP2") == 1 then
        return true
    else
        return false
    end
end

function Autopilot_APPR_check ()
    if ipc.readLvar("L:AB_AP_LOC2") == 1 then
        return true
    else
        return false
    end
end

function Autopilot_LOC_check ()
    if ipc.readLvar("L:AB_AP_LOC") == 1 then
        return true
    else
        return false
    end
end

function Autopilot_both_on ()
    Autopilot_AP1_on ()
    Autopilot_AP2_on ()
end

function Autopilot_both_off ()
    Autopilot_AP1_off ()
    Autopilot_AP2_off ()
end

function Autopilot_AP1_on ()
    LVarSet = "L:AB_AP_AP1"
    ipc.writeLvar(LVarSet, 1)
    SmallOverheadPushButtons ()
    if Autopilot_AP2_check() and not Autopilot_APPR_check() then
        Autopilot_AP2_off()
    end
    DspShow ("AP1", "on")
end

function Autopilot_AP1_off ()
    LVarSet = "L:AB_AP_AP1"
    ipc.writeLvar(LVarSet, 0)
    SmallOverheadPushButtons ()
    DspShow ("AP1", "off")
end

function Autopilot_AP1_toggle ()
	if _tl("L:AB_AP_AP1", 0) then
		Autopilot_AP1_on ()
	else
		Autopilot_AP1_off ()
	end
end

function Autopilot_AP2_on ()
    LVarSet = "L:AB_AP_AP2"
    ipc.writeLvar(LVarSet, 1)
    SmallOverheadPushButtons ()
    if Autopilot_AP1_check() and not Autopilot_APPR_check() then
        Autopilot_AP1_off()
    end
    DspShow ("AP2", "on")
end

function Autopilot_AP2_off ()
    LVarSet = "L:AB_AP_AP2"
    ipc.writeLvar(LVarSet, 0)
    SmallOverheadPushButtons ()
    DspShow ("AP2", "off")
end

function Autopilot_AP2_toggle ()
	if _tl("L:AB_AP_AP2", 0) then
		Autopilot_AP2_on ()
	else
		Autopilot_AP2_off ()
	end
end

function Autopilot_Disengage ()
    if ipc.readLvar("L:AB_AP_AP1") == 1 or
        ipc.readLvar("L:AB_AP_AP2") == 1 then
        Autopilot_AP1_off()
        Autopilot_AP2_off()
    end
end

function Autopilot_ATHR_on ()
    LVarSet = "L:AB_AP_ATHR"
    ipc.writeLvar(LVarSet, 1)
    SmallOverheadPushButtons ()
    DspShow ("ATHR", "on")
end

function Autopilot_ATHR_off ()
    LVarSet = "L:AB_AP_ATHR"
    ipc.writeLvar(LVarSet, 0)
    SmallOverheadPushButtons ()
    DspShow ("ATHR", "off")
end

function Autopilot_ATHR_toggle ()
	if _tl("L:AB_AP_ATHR") then
		Autopilot_ATHR_on ()
	else
		Autopilot_ATHR_off ()
	end
end

function Autopilot_LOC_on ()
    -- Switch off APP if on
    if ipc.readLvar("L:AB_AP_LOC2") == 1 then
        Autopilot_APPR_off ()
    end
    -- Switch on LOC
    LVarSet = "L:AB_AP_LOC"
    ipc.writeLvar(LVarSet, 1)
    SmallOverheadPushButtons ()
    DspShow ("LOC", "on")

end

function Autopilot_LOC_off ()
    LVarSet = "L:AB_AP_LOC"
    ipc.writeLvar(LVarSet, 0)
    SmallOverheadPushButtons ()
    DspShow ("LOC", "off")
end

function Autopilot_LOC_toggle ()
	if _tl("L:AB_AP_LOC", 0) then
		Autopilot_LOC_on ()
	else
		Autopilot_LOC_off ()
	end
end

function Autopilot_APPR_on ()
    -- Switch off LOC if on
    if ipc.readLvar("L:AB_AP_LOC") == 1 then Autopilot_LOC_off () end
    -- Switch on LOC
    LVarSet = "L:AB_AP_LOC2"
    ipc.writeLvar(LVarSet, 1)
    SmallOverheadPushButtons ()
    DspShow ("APPR", "on")
end

function Autopilot_APPR_off ()
    LVarSet = "L:AB_AP_LOC2"
    ipc.writeLvar(LVarSet, 0)
    SmallOverheadPushButtons ()
    if Autopilot_AP1_check () and Autopilot_AP2_check () then
        Autopilot_AP2_off()
    end
    DspShow ("APPR", "off")
end

function Autopilot_APPR_toggle ()
	if _tl("L:AB_AP_LOC2", 0) then
		Autopilot_APPR_on ()
	else
		Autopilot_APPR_off ()
	end
end

function Autopilot_EXPED_on ()
    LVarSet = "L:AB_AP_EXP"
    ipc.writeLvar(LVarSet, 1)
    SmallOverheadPushButtons ()
    DspShow ("EXPD", "on")
end

function Autopilot_EXPED_off ()
    LVarSet = "L:AB_AP_EXP"
    ipc.writeLvar(LVarSet, 0)
    SmallOverheadPushButtons ()
    DspShow ("EXPD", "off")
end

function Autopilot_EXPED_toggle ()
	if _tl("L:AB_AP_EXP", 0) then
		Autopilot_EXPED_on ()
	else
		Autopilot_EXPED_off ()
	end
end

-- SPD
function Autopilot_SPD_set ()
    LVarSet = "L:AB_AP_SPDmode"
    ipc.writeLvar(LVarSet, -1)
    -- cancel override timer
    ipc.writeLvar("FCU_Managed_SPDoverride_val", 0)
    ipc.writeLvar("FCU_Managed_SPDdisp_override", 0)
    Button3 ()
    AB_DspSPD ()
    DspShow ("SPD", "set")
end

function Autopilot_SPD_managed ()
    LVarSet = "L:AB_AP_SPDmode"
    ipc.writeLvar(LVarSet, 1)
    SpdMachVar = ipc.readLvar("AB_AP_SPDMACH")
    Button3 ()
    AB_DspSPD ()
    DspShow ("SPD", "mngd")
end

function Autopilot_SPD_toggle ()
	if _tl("L:AB_AP_SPDmode_set", 1) then
		Autopilot_SPD_set ()
	else
		Autopilot_SPD_managed ()
	end
end

-- HDG
function Autopilot_HDG_set ()
    LVarSet = "L:AB_AP_HDGmode"
    ipc.writeLvar(LVarSet, -1)
    LVarSet = "L:AB_AP_HDGmode_set"
    ipc.writeLvar(LVarSet, -1)
    Button3 ()
--    AB_DspHDG()
    DspShow ("HDG", "set")
end

function Autopilot_HDG_managed ()
_log('HDG mngd')
    LVarSet = "L:AB_AP_HDGmode"
    ipc.writeLvar(LVarSet, 1)
    LVarSet = "L:AB_AP_HDGmode_set"
    ipc.writeLvar(LVarSet, 1)
    Button3 ()
--    AB_DspHDG()
	DspShow ("HDG", "mngd")
end

function Autopilot_HDG_toggle ()
	if _tl("L:AB_AP_HDGmode_set", 1) then
		Autopilot_HDG_set ()
	else
		Autopilot_HDG_managed ()
	end
end

-- ALT
function Autopilot_ALT_set ()
_log('ALT set')
    LVarSet = "L:AB_AP_ALTmode"
    ipc.writeLvar(LVarSet, -1)
    Button3 ()
	AB_DspVVS ()
    AB_DspALT()
    DspShow ("ALT", "set")
end

function Autopilot_ALT_managed ()
_log('ALT mngd')
    LVarSet = "L:AB_AP_ALTmode"
    ipc.writeLvar(LVarSet, 1)
    Button3 ()
    AB_DspALT()
    DspShow ("ALT", "mngd")
end

function Autopilot_ALT_toggle ()
    if _tl("L:AB_AP_ALTmode_set", 1) then
		Autopilot_ALT_set ()
	else
		Autopilot_ALT_managed ()
	end
end

--VVS
function Autopilot_VS_level ()
    --ipc.writeLvar("AB_AP_ALTmode", 0)
    ipc.writeLvar("AB_AP_VS_Select2", 0)
    ipc.writeLvar("AB_AP_VS_Select3", 0)
    ipc.writeLvar("AB_AP_VSlevel", 1)
    DspShow ("VS", "lvl")
    Button3 ()
end

function Autopilot_VS_pull ()
    ipc.writeLvar("AB_AP_VSlevel", -1)
    ipc.writeLvar("AB_AP_VSenb", 1)
    ipc.writeLvar("AB_AP_KNOBALT", 1)
    DspShow ("VS", "set")
    AB_AP_DES = 2
    Button3 ()
end

function Autopilot_FD_on ()
    LVarSet = "L:AB_MPL_FD"
    ipc.writeLvar(LVarSet, 1)
    SmallOverheadPushButtons ()
    DspShow ("FD", "on")
end

function Autopilot_FD_off ()
    LVarSet = "L:AB_MPL_FD"
    ipc.writeLvar(LVarSet, 0)
    SmallOverheadPushButtons ()
    DspShow ("FD", "off")
end

function Autopilot_FD_toggle ()
	if _tl("L:AB_MPL_FD", 0) then
		Autopilot_FD_on ()
	else
		Autopilot_FD_off ()
	end
end

function Autopilot_LS_on ()
    LVarSet = "L:AB_MPL_ILS"
    ipc.writeLvar(LVarSet, 1)
    SmallOverheadPushButtons ()
    DspILS(true)
    DspShow ("LS", "on")
end

function Autopilot_LS_off ()
    LVarSet = "L:AB_MPL_ILS"
    ipc.writeLvar(LVarSet, 0)
    SmallOverheadPushButtons ()
    DspILS(false)
    DspShow ("LS", "off")
end

function Autopilot_LS_toggle ()
	if _tl("L:AB_MPL_ILS", 0) then
		Autopilot_LS_on ()
	else
		Autopilot_LS_off ()
	end
end

function SPD_MACH_spd ()
    ipc.writeLvar("AB_AP_SPDMACH", 0)
    DspSPDtxt(0)
    AB_DspSPD()
    SmallOverheadPushButtons ()
    DspShow("Disp","SPD")
end

function SPD_MACH_mach ()
    ipc.writeLvar("AB_AP_SPDMACH", 1)
    DspSPDtxt(1)
    AB_DspSPD()
    SmallOverheadPushButtons ()
    DspShow ("Disp", "MACH")
end

function SPD_MACH_toggle ()
	if _tl("AB_AP_SPDMACH", 1) then
       SPD_MACH_spd ()
	else
       SPD_MACH_mach ()
	end
end

function HDG_TRK_hdg ()
    ipc.writeLvar("AB_AP_HDGTRK", 0)
    DspHDGtxt(0)
    SmallOverheadPushButtons ()
    DspShow ("Disp", "HDG")
end

function HDG_TRK_trk ()
    ipc.writeLvar("AB_AP_HDGTRK", 1)
    DspHDGtxt(1)
    SmallOverheadPushButtons ()
    DspShow ("Disp", "TRK")
end

function HDG_TRK_toggle ()
	if _tl("AB_AP_HDGTRK", 1) then
       HDG_TRK_hdg ()
	else
       HDG_TRK_trk ()
	end
end

-- ## AP Rotaries  #################################################

-- SPED rotaries
function AB_SPD_plus ()
    SpdMachVar = ipc.readLvar("AB_AP_SPDMACH")
    if SpdMachVar == 0 then
        LVarSet = "L:AB_AP_SPEED_Select"
        LVarGet = round(ipc.readLvar(LVarSet))

        if LVarGet < 399 then
            AddVar = 1
        else
            AddVar = 0
        end
        DspSPD(LVarGet + AddVar)
    elseif SpdMachVar == 1 then
        LVarSet = "L:AB_AP_Mach_Select"
        LVarGet = ipc.readLvar(LVarSet)
        if LVarGet < 0.80 then
            AddVar = 0.01
        else
            AddVar = 0.00
        end
        DspSPDs(tostring(LVarGet + AddVar + 0.005))
    end
    ipc.sleep(20)
    ipc.writeLvar(LVarSet, LVarGet + AddVar)
end

function AB_SPD_plusfast ()
    if SpdMachVar == 0 then
        LVarSet = "L:AB_AP_SPEED_Select"
        LVarGet = round(ipc.readLvar(LVarSet))
        if LVarGet < 399 then
            AddVar = 10
        else
            AddVar = 0
        end
        DspSPD(LVarGet + AddVar)
    elseif SpdMachVar == 1 then
        LVarSet = "L:AB_AP_Mach_Select"
        LVarGet = ipc.readLvar(LVarSet)
        if LVarGet < 0.80 then
            AddVar = 0.10
        else
            AddVar = 0.00
        end
        DspSPDs(tostring(LVarGet + AddVar + 0.005))
    end
    ipc.sleep(20)
    ipc.writeLvar(LVarSet, LVarGet + AddVar)
end

function AB_SPD_minus ()
    SpdMachVar = ipc.readLvar("AB_AP_SPDMACH")
    if SpdMachVar == 0 then
        LVarSet = "L:AB_AP_SPEED_Select"
        LVarGet = round(ipc.readLvar(LVarSet))
        if LVarGet > 100 then
            AddVar = 1
        else
            AddVar = 0
        end
        DspSPD(LVarGet - AddVar)
    elseif SpdMachVar == 1 then
        LVarSet = "L:AB_AP_Mach_Select"
        LVarGet = ipc.readLvar(LVarSet)
        if LVarGet > 0.16 then
            AddVar = 0.01
        else
            AddVar = 0.00
        end
        DspSPDs(tostring(LVarGet + AddVar + 0.005))
    end
    ipc.sleep(20)
    ipc.writeLvar(LVarSet, LVarGet - AddVar)
end

function AB_SPD_minusfast ()
    SpdMachVar = ipc.readLvar("AB_AP_SPDMACH")
    if SpdMachVar == 0 then
        LVarSet = "L:AB_AP_SPEED_Select"
        LVarGet = round(ipc.readLvar(LVarSet))
        if LVarGet > 110 then
            AddVar = 10
        else
            AddVar = 0
        end
        DspSPD(LVarGet - AddVar)
    elseif SpdMachVar == 1 then
        LVarSet = "L:AB_AP_Mach_Select"
        LVarGet = ipc.readLvar(LVarSet)
        if LVarGet > 0.16 then
            AddVar = 0.10
        else
            AddVar = 0.00
        end
        DspSPDs(tostring(LVarGet - AddVar + 0.005))
    end
    ipc.sleep(20)
    ipc.writeLvar(LVarSet, LVarGet - AddVar)
end

-- HDG rotaties
function AB_HDG_plus ()
    AB_hdgtrk = ipc.readLvar("L:AB_AP_HDGTRK")
    AB_drift = round(ipc.readLvar("L:AB_AP_HDGTRK"))
    if AB_hdgtrk == 0 then
        LVarSet = "AB_AP_HDG_Select"
    else
        LVarSet = "Autopilot_TRK_set"
    end
    LVarGet = ipc.readLvar(LVarSet)
    AddVar = LVarGet + 1
    if AddVar > 359 then
        AddVar = 0
    end
    DspHDG(AddVar)
    ipc.writeLvar(LVarSet, AddVar)
end

function AB_HDG_plusfast ()
    AB_hdgtrk = ipc.readLvar("L:AB_AP_HDGTRK")
    if AB_hdgtrk == 0 then
        LVarSet = "AB_AP_HDG_Select"
    else
        LVarSet = "Autopilot_TRK_set"
    end
    AddVar = LVarGet + 10
    if AddVar > 359 then
        AddVar = AddVar - 359
    end
    DspHDG(AddVar)
    ipc.writeLvar(LVarSet, AddVar)
end

function AB_HDG_minus ()
    AB_hdgtrk = ipc.readLvar("L:AB_AP_HDGTRK")
    if AB_hdgtrk == 0 then
        LVarSet = "AB_AP_HDG_Select"
    else
        LVarSet = "Autopilot_TRK_set"
    end
    LVarGet = round(ipc.readLvar(LVarSet))
    AddVar = LVarGet - 1
    if LVarGet < 0 then
        AddVar = 359
    end
    DspHDG(AddVar)
    ipc.writeLvar(LVarSet, AddVar)
end

function AB_HDG_minusfast ()
    AB_hdgtrk = ipc.readLvar("L:AB_AP_HDGTRK")
    if AB_hdgtrk == 0 then
        LVarSet = "AB_AP_HDG_Select"
    else
        LVarSet = "Autopilot_TRK_set"
    end
    LVarGet = round(ipc.readLvar(LVarSet))
    AddVar = LVarGet - 10
    if LVarGet < 0 then
        AddVar = AddVar + 359
    end
    DspHDG(AddVar)
    ipc.writeLvar(LVarSet, AddVar)
end

-- ALT
function AB_ALT_Step_toggle ()
    LVarSet = "L:AB_AP_ALTSTEP"
    if ipc.readLvar(LVarSet) == 0 then
        AB_ALT_Step_1000 ()
    else
        AB_ALT_Step_100 ()
    end
end

function AB_ALT_Step_100 ()
    LVarSet = "L:AB_AP_ALTSTEP"
    ipc.writeLvar(LVarSet, 0)
    DspShow("Step","100")
end

function AB_ALT_Step_1000 ()
    LVarSet = "L:AB_AP_ALTSTEP"
    ipc.writeLvar(LVarSet, 1)
    DspShow("Step","1000")
end

function AB_ALT_plus ()
    if ipc.readLvar("L:AB_AP_ALTSTEP") == 0 then
        AddVar = 100
    else
        AddVar = 1000
    end
    LVarSet = "L:AB_AP_ALT_Select"
    LVarGet = ipc.readLvar(LVarSet)
    if LVarGet + AddVar <= 41000 then
        ipc.writeLvar(LVarSet, LVarGet + AddVar)
    else
        ipc.writeLvar(LVarSet, 41000)
    end
    AB_DspALT ()
end

function AB_ALT_plusfast ()
	LVarSet = "L:AB_AP_ALT_Select"
    LVarGet = ipc.readLvar(LVarSet)
    AddVar = 1000
    if LVarGet + AddVar <= 41000 then
        ipc.writeLvar(LVarSet, LVarGet + AddVar)
    else
        ipc.writeLvar(LVarSet, 41000)
    end
    AB_DspALT ()
end

function AB_ALT_minus ()
    if ipc.readLvar("L:AB_AP_ALTSTEP") == 0 then
        AddVar = 100
    else
        AddVar = 1000
    end
    LVarSet = "L:AB_AP_ALT_Select"
    LVarGet = ipc.readLvar(LVarSet)
    if LVarGet - AddVar >= 100 then
        ipc.writeLvar(LVarSet, LVarGet - AddVar)
    else
        ipc.writeLvar(LVarSet, 100)
    end
    AB_DspALT ()
end

function AB_ALT_minusfast ()
	LVarSet = "L:AB_AP_ALT_Select"
    LVarGet = ipc.readLvar(LVarSet)
    AddVar = 1000
    if LVarGet - AddVar >= 100 then
        ipc.writeLvar(LVarSet, LVarGet - AddVar)
    else
        ipc.writeLvar(LVarSet, 100)
    end
    AB_DspALT ()
end

function AB_VS_plus ()
local val
    if ipc.readLvar("AB_AP_HDGTRK") == 0 then
        LVarSet = "L:AB_AP_VS_Select2"
        LVarGet = ipc.readLvar(LVarSet)
        if LVarGet <= 59 then
            val = LVarGet + 1
            DspVVS(val)
            ipc.writeLvar(LVarSet, val)
        end
    else
        LVarSet = "L:AB_AP_FPA_Select2"
        LVarGet = ipc.readLvar(LVarSet)
        if LVarGet <= 9.8 then
            val = LVarGet + 0.1
            DspFPA(val)
            ipc.writeLvar(LVarSet, val)
        end
    end
end

function AB_VS_plusfast ()
local val
    if ipc.readLvar("AB_AP_HDGTRK") == 0 then
        LVarSet = "L:AB_AP_VS_Select2"
        LVarGet = ipc.readLvar(LVarSet)
        if LVarGet <= 55 then
            val = LVarGet + 5
            DspVVS(val)
            ipc.writeLvar(LVarSet, val)
        end
    else
        LVarSet = "L:AB_AP_FPA_Select2"
        LVarGet = ipc.readLvar(LVarSet)
        if LVarGet <= 9.8 then
            val = LVarGet + 0.1
            DspFPA(val)
            ipc.writeLvar(LVarSet, val)
        end
    end
end

function AB_VS_minus ()
local val
    if ipc.readLvar("AB_AP_HDGTRK") == 0 then
        LVarSet = "L:AB_AP_VS_Select2"
        LVarGet = ipc.readLvar(LVarSet)
        if LVarGet >= -59 then
            val = LVarGet - 1
            DspVVS(val)
            ipc.writeLvar(LVarSet, val)
        end
    else
        LVarSet = "L:AB_AP_FPA_Select2"
        LVarGet = ipc.readLvar(LVarSet)
        if LVarGet >= -9.8 then
            val = LVarGet - 0.1
            DspFPA(val)
            ipc.writeLvar(LVarSet, val)
        end
    end
end

function AB_VS_minusfast ()
local val
    if ipc.readLvar("AB_AP_HDGTRK") == 0 then
        LVarSet = "L:AB_AP_VS_Select2"
        LVarGet = ipc.readLvar(LVarSet)
        if LVarGet >= -55 then
            val = LVarGet - 5
            DspVVS(val)
            ipc.writeLvar(LVarSet, val)
        end
    else
        LVarSet = "L:AB_AP_FPA_Select2"
        LVarGet = ipc.readLvar(LVarSet)
        if LVarGet >= -9.8 then
            val = LVarGet - 0.1
            DspFPA(val)
            ipc.writeLvar(LVarSet, val)
        end
    end
end

-- ## Avionics ###############

function AB_Radios_on ()
    ipc.writeLvar("L:AB_PDS_RADIO_POWER", 1)
    SmallOverheadPushButtons ()
    DspShow ("Rdio", "on")
end

function AB_Radios_off ()
    ipc.writeLvar("L:AB_PDS_RADIO_POWER", 0)
    SmallOverheadPushButtons ()
    DspShow ("Rdio", "off")
end

function AB_Radios_toggle ()
	if _tl("AB_PDS_RADIO_POWER", 0) then
       AB_Radios_on ()
	else
       AB_Radios_off ()
	end
end


--------2.4
function PFD_Power_show ()
    var = ipc.readLvar("L:AB_MPL_PFD_Power")
    DspShow ("PFD", var*5 .. "%")
end

function PFD_Power_inc ()
    var = ipc.readLvar("L:AB_MPL_PFD_Power")
    if var < 20 then
        ipc.writeLvar("L:AB_MPL_PFD_Power", var + 1)
    end
    PFD_Power_show ()
end

function PFD_Power_dec ()
    var = ipc.readLvar("L:AB_MPL_PFD_Power")
    if var > 0 then
        ipc.writeLvar("L:AB_MPL_PFD_Power", var - 1)
    end
    PFD_Power_show ()
end

function PFD_Power_on ()
    ipc.writeLvar("L:AB_MPL_PFD_Power", OnVar)
    PFD_Power_show ()
end

function PFD_Power_off ()
    ipc.writeLvar("L:AB_MPL_PFD_Power", 0)
    PFD_Power_show ()
end

------------

function ND_Power_show ()
    var = ipc.readLvar("L:AB_MPL_ND_Bright")
    DspShow ("ND", var*5 .. "%")
end

function ND_Power_inc ()
    var = ipc.readLvar("L:AB_MPL_ND_Bright")

    if var < 20 then
        ipc.writeLvar("L:AB_MPL_ND_Bright", var + 1)
    end
    ND_Power_show ()
end

function ND_Power_dec ()
    var = ipc.readLvar("L:AB_MPL_ND_Bright")

    if var > 0 then
        ipc.writeLvar("L:AB_MPL_ND_Bright", var - 1)
    end
    ND_Power_show ()
end

function ND_Power_on ()
    ipc.writeLvar("L:AB_MPL_ND_Bright", OnVar)
    ND_Power_show ()
end

function ND_Power_off ()
    ipc.writeLvar("L:AB_MPL_ND_Bright", 0)
    ND_Power_show ()
end

-------

function ND_RadarPower_show ()
    var = ipc.readLvar("L:AB_MPL_NDTERR_Bright")
    DspShow ("RDR", var*5 .. "%")
end

function ND_RadarPower_inc ()
    var = ipc.readLvar("L:AB_MPL_NDTERR_Bright")
    if var < 20 then
        ipc.writeLvar("L:AB_MPL_NDTERR_Bright", var + 1)
    end
    ND_RadarPower_show()
end

function ND_RadarPower_dec ()
    var = ipc.readLvar("L:AB_MPL_NDTERR_Bright")
    if var > 0 then
        ipc.writeLvar("L:AB_MPL_NDTERR_Bright", var - 1)
    end
    ND_RadarPower_show()
end

function ND_RadarPower_on ()
    ipc.writeLvar("L:AB_MPL_NDTERR_Bright", OnVar)
    ND_RadarPower_show ()
end

function ND_RadarPower_off ()
    ipc.writeLvar("L:AB_MPL_NDTERR_Bright", 0)
    ND_RadarPower_show ()
end

-------

function ECAMU_Power_show ()
    var = ipc.readLvar("L:AB_MPL_ECAMU_Power")
    DspShow ("ECMU", var*5 .. "%")
end

function ECAMU_Power_inc ()
    var = ipc.readLvar("L:AB_MPL_ECAMU_Power")
    if var < 20 then
        ipc.writeLvar("L:AB_MPL_ECAMU_Power", var + 1)
    end
    ECAMU_Power_show ()
end

function ECAMU_Power_dec ()
    var = ipc.readLvar("L:AB_MPL_ECAMU_Power")
    if var > 0 then
        ipc.writeLvar("L:AB_MPL_ECAMU_Power", var - 1)
    end
    ECAMU_Power_show ()
end

function ECAMU_Power_on ()
    ipc.writeLvar("L:AB_MPL_ECAMU_Power", OnVar)
    ECAMU_Power_show ()
end

function ECAMU_Power_off ()
    ipc.writeLvar("L:AB_MPL_ECAMU_Power", 0)
    ECAMU_Power_show ()
end

------------

function ECAML_Power_show ()
    var = ipc.readLvar("L:AB_MPL_ECAML_Power")
    DspShow ("ECML", var*5 .. "%")
end

function ECAML_Power_inc ()
    var = ipc.readLvar("L:AB_MPL_ECAML_Power")
    if var < 20 then
        ipc.writeLvar("L:AB_MPL_ECAML_Power", var + 1)
    end
    ECAML_Power_show ()
end

function ECAML_Power_dec ()
    var = ipc.readLvar("L:AB_MPL_ECAML_Power")
    if var > 0 then
        ipc.writeLvar("L:AB_MPL_ECAML_Power", var - 1)
    end
    ECAML_Power_show ()
end

function ECAML_Power_on ()
    ipc.writeLvar("L:AB_MPL_ECAML_Power", OnVar)
    ECAML_Power_show ()
end

function ECAML_Power_off ()
    ipc.writeLvar("L:AB_MPL_ECAML_Power", 0)
    ECAML_Power_show ()
end

function AllDisp_Power_inc ()
    PFD_Power_inc ()
    ND_Power_inc ()
    ND_RadarPower_inc ()
    ECAMU_Power_inc ()
    ECAML_Power_inc ()
end

function AllDisp_Power_dec ()
    PFD_Power_dec ()
    ND_Power_dec ()
    ND_RadarPower_dec ()
    ECAMU_Power_dec ()
    ECAML_Power_dec ()
end

function AB_All_Avionics_on ()
    PFD_Power_on ()
    _sleep(200,500)
    ND_Power_on ()
    _sleep(200,500)
    ECAMU_Power_on ()
    _sleep(200,500)
    ECAML_Power_on ()
    _sleep(200,500)
    ND_RadarPower_on ()
    _sleep(200,500)
    AB_Radios_on ()
end

function AB_All_Avionics_off ()
    AB_Radios_off ()
    _sleep(200,500)
    ECAML_Power_off ()
    _sleep(200,500)
    ECAMU_Power_off ()
    _sleep(200,500)
    ND_Power_off ()
    _sleep(200,500)
    ND_RadarPower_off ()
    PFD_Power_off ()
end

-- ## ND controls #####################################

function ND_CSTR_on ()
    ipc.writeLvar("L:AB_MPL_ND_CSTR", 1)
	ipc.writeLvar("L:AB_MPL_ND_WPT", 0)
	ipc.writeLvar("L:AB_MPL_ND_VOR", 0)
	ipc.writeLvar("L:AB_MPL_ND_NDB", 0)
	ipc.writeLvar("L:AB_MPL_ND_ARPT", 0)
    SmallOverheadPushButtons ()
    DspShow ("ND", "CSTR")
end

function ND_CSTR_off ()
    ipc.writeLvar("L:AB_MPL_ND_CSTR", 0)
	ipc.writeLvar("L:AB_MPL_ND_WPT", 0)
	ipc.writeLvar("L:AB_MPL_ND_VOR", 0)
	ipc.writeLvar("L:AB_MPL_ND_NDB", 0)
	ipc.writeLvar("L:AB_MPL_ND_ARPT", 0)
    SmallOverheadPushButtons ()
    DspShow ("ND", "CSTR")
end

function ND_CSTR_toggle ()
	if ipc.readLvar("L:AB_MPL_ND_CSTR") == 0 then
        ND_CSTR_on ()
    else
        ND_CSTR_off ()
    end
end

function ND_WPT_on ()
    ipc.writeLvar("L:AB_MPL_ND_CSTR", 0)
	ipc.writeLvar("L:AB_MPL_ND_WPT", 1)
	ipc.writeLvar("L:AB_MPL_ND_VOR", 0)
	ipc.writeLvar("L:AB_MPL_ND_NDB", 0)
	ipc.writeLvar("L:AB_MPL_ND_ARPT", 0)
    SmallOverheadPushButtons ()
    DspShow ("ND", "WPT")
end

function ND_WPT_off ()
    ipc.writeLvar("L:AB_MPL_ND_CSTR", 0)
	ipc.writeLvar("L:AB_MPL_ND_WPT", 0)
	ipc.writeLvar("L:AB_MPL_ND_VOR", 0)
	ipc.writeLvar("L:AB_MPL_ND_NDB", 0)
	ipc.writeLvar("L:AB_MPL_ND_ARPT", 0)
    SmallOverheadPushButtons ()
    DspShow ("ND", "WPT")
end

function ND_WPT_toggle ()
	if ipc.readLvar("L:AB_MPL_ND_WPT") == 0 then
        ND_WPT_on ()
    else
        ND_WPT_off ()
    end
end

function ND_VOR_on ()
    ipc.writeLvar("L:AB_MPL_ND_CSTR", 0)
	ipc.writeLvar("L:AB_MPL_ND_WPT", 0)
	ipc.writeLvar("L:AB_MPL_ND_VOR", 1)
	ipc.writeLvar("L:AB_MPL_ND_NDB", 0)
	ipc.writeLvar("L:AB_MPL_ND_ARPT", 0)
    SmallOverheadPushButtons ()
    DspShow ("ND", "VOR")
end

function ND_VOR_off ()
    ipc.writeLvar("L:AB_MPL_ND_CSTR", 0)
	ipc.writeLvar("L:AB_MPL_ND_WPT", 0)
	ipc.writeLvar("L:AB_MPL_ND_VOR", 0)
	ipc.writeLvar("L:AB_MPL_ND_NDB", 0)
	ipc.writeLvar("L:AB_MPL_ND_ARPT", 0)
    SmallOverheadPushButtons ()
    DspShow ("ND", "VOR")
end

function ND_VOR_toggle ()
	if ipc.readLvar("L:AB_MPL_ND_VOR") == 0 then
        ND_VOR_on ()
    else
        ND_VOR_off ()
    end
end

function ND_NDB_on ()
    ipc.writeLvar("L:AB_MPL_ND_CSTR", 0)
	ipc.writeLvar("L:AB_MPL_ND_WPT", 0)
	ipc.writeLvar("L:AB_MPL_ND_VOR", 0)
	ipc.writeLvar("L:AB_MPL_ND_NDB", 1)
	ipc.writeLvar("L:AB_MPL_ND_ARPT", 0)
    SmallOverheadPushButtons ()
    DspShow ("ND", "NDB")
end

function ND_NDB_off ()
    ipc.writeLvar("L:AB_MPL_ND_CSTR", 0)
	ipc.writeLvar("L:AB_MPL_ND_WPT", 0)
	ipc.writeLvar("L:AB_MPL_ND_VOR", 0)
	ipc.writeLvar("L:AB_MPL_ND_NDB", 0)
	ipc.writeLvar("L:AB_MPL_ND_ARPT", 0)
    SmallOverheadPushButtons ()
    DspShow ("ND", "NDB")
end

function ND_NDB_toggle ()
	if ipc.readLvar("L:AB_MPL_ND_NDB") == 0 then
        ND_NDB_on ()
    else
        ND_NDB_off ()
    end
end

function ND_ARPT_on ()
    ipc.writeLvar("L:AB_MPL_ND_CSTR", 0)
	ipc.writeLvar("L:AB_MPL_ND_WPT", 0)
	ipc.writeLvar("L:AB_MPL_ND_VOR", 0)
	ipc.writeLvar("L:AB_MPL_ND_NDB", 0)
	ipc.writeLvar("L:AB_MPL_ND_ARPT", 1)
    SmallOverheadPushButtons ()
    DspShow ("ND", "ARPT")
end

function ND_ARPT_off ()
    ipc.writeLvar("L:AB_MPL_ND_CSTR", 0)
	ipc.writeLvar("L:AB_MPL_ND_WPT", 0)
	ipc.writeLvar("L:AB_MPL_ND_VOR", 0)
	ipc.writeLvar("L:AB_MPL_ND_NDB", 0)
	ipc.writeLvar("L:AB_MPL_ND_ARPT", 0)
    SmallOverheadPushButtons ()
    DspShow ("ND", "ARPT")
end

function ND_ARPT_toggle ()
	if ipc.readLvar("L:AB_MPL_ND_ARPT") == 0 then
        ND_ARPT_on ()
    else
        ND_ARPT_off ()
    end
end

function ND_DATA_toggle ()
    ND_Data_CSTR = ipc.readLvar("L:AB_MPL_ND_CSTR")
    ND_Data_WPT = ipc.readLvar("L:AB_MPL_ND_WPT")
	ND_Data_VOR = ipc.readLvar("L:AB_MPL_ND_VOR")
    ND_Data_NDB = ipc.readLvar("L:AB_MPL_ND_NDB")
    ND_Data_ARPT = ipc.readLvar("L:AB_MPL_ND_ARPT")
    if ND_Data_CSTR == 1 then
        ND_DATAvar = 1
    elseif ND_Data_WPT == 1 then
        ND_DATAvar = 2
    elseif ND_Data_VOR == 1 then
        ND_DATAvar = 3
    elseif ND_Data_NDB == 1 then
        ND_DATAvar = 4
    elseif ND_Data_ARPT == 1 then
        ND_DATAvar = 5
    end
    if ND_DATAvar == 1 then
        ND_WPT_on ()
    elseif ND_DATAvar == 2 then
        ND_VOR_on ()
    elseif ND_DATAvar == 3 then
        ND_NDB_on ()
    elseif ND_DATAvar == 4 then
        ND_ARPT_on ()
    elseif ND_DATAvar == 5 then
        ND_CSTR_on ()
    end
    ND_MODE_show()
end

function ND_MODE_show ()
	NGrng = ipc.readLvar("L:AB_MPL_ND_Mode")
    if NGrng == 0 then
        NDmodeTxt = "LS"
    elseif NGrng == 1 then
        NDmodeTxt = "VOR"
    elseif NGrng == 2 then
        NDmodeTxt = "NAV"
    elseif NGrng == 3 then
        NDmodeTxt = "ARC"
    elseif NGrng == 4 then
        NDmodeTxt = "PLAN"
    end
    DspShow ("NDmd", NDmodeTxt)
end

function ND_MODE_LS ()
	ipc.writeLvar("L:AB_MPL_ND_Mode", 0)
    ASC_KnobRotate ()
    ND_MODE_show ()
end

function ND_MODE_VOR ()
	ipc.writeLvar("L:AB_MPL_ND_Mode", 1)
    ASC_KnobRotate ()
    ND_MODE_show ()
end

function ND_MODE_NAV ()
	ipc.writeLvar("L:AB_MPL_ND_Mode", 2)
    ASC_KnobRotate ()
    ND_MODE_show ()
end

function ND_MODE_ARC ()
	ipc.writeLvar("L:AB_MPL_ND_Mode", 3)
    ASC_KnobRotate ()
    ND_MODE_show ()
end
function ND_MODE_PLAN ()
	ipc.writeLvar("L:AB_MPL_ND_Mode", 4)
    ASC_KnobRotate ()
    ND_MODE_show ()
end

function ND_MODE_inc ()
    nd_mode = ipc.readLvar("L:AB_MPL_ND_Mode")
	nd_mode = nd_mode + 1
	if nd_mode > 4 then
        nd_mode = 4
    end
	ipc.writeLvar("L:AB_MPL_ND_Mode", nd_mode)
    ASC_KnobRotate ()
    ND_MODE_show ()
end

function ND_MODE_dec ()
    nd_mode = ipc.readLvar("L:AB_MPL_ND_Mode")
	nd_mode = nd_mode - 1
	if nd_mode < 0 then
        nd_mode = 0
    end
	ipc.writeLvar("L:AB_MPL_ND_Mode", nd_mode)
	ASC_KnobRotate ()
    ND_MODE_show ()
end

function ND_RANGE_show ()
	NGrng = ipc.readLvar("L:AB_MPL_ND_Range")
    if NGrng == 0 then
        NDrngTxt = "10"
    elseif NGrng == 1 then
        NDrngTxt = "20"
    elseif NGrng == 2 then
        NDrngTxt = "40"
    elseif NGrng == 3 then
        NDrngTxt = "80"
    elseif NGrng == 4 then
        NDrngTxt = "160"
    elseif NGrng == 5 then
        NDrngTxt = "320"
    end
    DspShow ("NDrg", NDrngTxt)
end

function ND_RANGE_10 ()
    ipc.writeLvar("L:AB_MPL_ND_Range", 0)
    ipc.sleep(10)
    ASC_KnobRotate ()
    ND_RANGE_show ()
end

function ND_RANGE_20 ()
    ipc.writeLvar("L:AB_MPL_ND_Range", 1)
    ipc.sleep(10)
    ASC_KnobRotate ()
    ND_RANGE_show ()
end

function ND_RANGE_40 ()
    ipc.writeLvar("L:AB_MPL_ND_Range", 2)
    ipc.sleep(10)
    ASC_KnobRotate ()
    ND_RANGE_show ()
end

function ND_RANGE_80 ()
    ipc.writeLvar("L:AB_MPL_ND_Range", 3)
    ipc.sleep(10)
    ASC_KnobRotate ()
    ND_RANGE_show ()
end

function ND_RANGE_160 ()
    ipc.writeLvar("L:AB_MPL_ND_Range", 4)
    ipc.sleep(10)
    ASC_KnobRotate ()
    ND_RANGE_show ()
end

function ND_RANGE_320 ()
    ipc.writeLvar("L:AB_MPL_ND_Range", 5)
    ipc.sleep(10)
    ASC_KnobRotate ()
    ND_RANGE_show ()
end

function ND_RANGE_inc ()
	i = ipc.readLvar("L:AB_MPL_ND_Range")
	if i < 5 then
		ipc.writeLvar("L:AB_MPL_ND_Range", i+1)
		ipc.sleep(10)
        ASC_KnobRotate ()
        ND_RANGE_show ()
	end
end

function ND_RANGE_dec ()
	i = ipc.readLvar("L:AB_MPL_ND_Range")
	if i > 0 then
		ipc.writeLvar("L:AB_MPL_ND_Range", i-1)
		ipc.sleep(10)
        ASC_KnobRotate ()
        ND_RANGE_show ()
	end
end

function ND_ARROW1_vor ()
    LVarSet = "L:AB_MPL_ND_Arrow1"
    ipc.writeLvar(LVarSet, 0)
    DspShow ("VOR", "1")
    LightSwitch ()
end

function ND_ARROW1_adf ()
    LVarSet = "L:AB_MPL_ND_Arrow1"
    ipc.writeLvar(LVarSet, 2)
    DspShow ("ADF", "1")
    LightSwitch ()
end

function ND_ARROW1_off ()
    LVarSet = "L:AB_MPL_ND_Arrow1"
    ipc.writeLvar(LVarSet, 1)
    LightSwitch ()
end

function ND_ARROW2_vor ()
    LVarSet = "L:AB_MPL_ND_Arrow2"
    ipc.writeLvar(LVarSet, 0)
    DspShow ("VOR", "2")
    LightSwitch ()
end

function ND_ARROW2_adf ()
    LVarSet = "L:AB_MPL_ND_Arrow2"
    ipc.writeLvar(LVarSet, 2)
    LightSwitch ()
    DspShow ("ADF", "2")
end

function ND_ARROW2_off ()
    LVarSet = "L:AB_MPL_ND_Arrow2"
    ipc.writeLvar(LVarSet, 1)
    LightSwitch ()
end

function ND_ARROW1_right ()
    NDArr1 = ipc.readLvar("AB_MPL_ND_Arrow1")
    if NDArr1 == 2 then
        ND_ARROW1_off ()
    elseif NDArr1 == 1 then
        ND_ARROW1_vor ()
    end
end

function ND_ARROW1_left ()
    NDArr1 = ipc.readLvar("AB_MPL_ND_Arrow1")
    if NDArr1 == 0 then
        ND_ARROW1_off ()
    elseif NDArr1 == 1 then
        ND_ARROW1_adf ()
    end
end

function ND_ARROW2_right ()
    NDArr2 = ipc.readLvar("AB_MPL_ND_Arrow2")
    if NDArr2 == 2 then
        ND_ARROW2_off ()
    elseif NDArr2 == 1 then
        ND_ARROW2_vor ()
    end
end

function ND_ARROW2_left ()
    NDArr2 = ipc.readLvar("AB_MPL_ND_Arrow2")
    if NDArr2 == 0 then
        ND_ARROW2_off ()
    elseif NDArr2 == 1 then
        ND_ARROW2_adf ()
    end
end

-- ## Barometric #######
function AB_BARO_show ()
    BaroVarhPa = ipc.readLvar("LINDA_Baro_Hpa")
    BaroVarinHg = ipc.readLvar("LINDA_Baro_inHg")
    BaroUnitVar = ipc.readLvar("L:AB_MPL_Baro_Unit")
    if BaroUnitVar == 0 then
        BaroText1 = "hPa"
        BaroText2 = BaroVarhPa
    elseif BaroUnitVar == 1 then
        BaroText1 = "inHg"
        BaroText2 = BaroVarinHg
    end
    DspShow (BaroText1, BaroText2)
end

function AB_BARO_inc ()
    if ipc.readLvar("AB_MPL_Baro_Unit") == 0 then
        ipc.control(65883)
        ipc.control(65883)
        ipc.control(65883)
    elseif ipc.readLvar("AB_MPL_Baro_Unit") == 1 then
        ipc.control(65883)
    end
    ipc.sleep(50)
    AB_BARO_show ()
end

function AB_BARO_dec ()
    if ipc.readLvar("AB_MPL_Baro_Unit") == 0 then
        ipc.control(65884)
        ipc.control(65884)
        ipc.control(65884)
    elseif ipc.readLvar("AB_MPL_Baro_Unit") == 1 then
        ipc.control(65884)
    end
    ipc.sleep(50)
    AB_BARO_show ()
end

function Baro_MODE_std ()
    LVarSet = "L:AB_MPL_Baro_STD"
	ipc.writeLvar(LVarSet, 1)
    SmallOverheadPushButtons ()
    DspShow ("BARO", "std")
end

function Baro_MODE_set ()
    LVarSet = "L:AB_MPL_Baro_STD"
	ipc.writeLvar(LVarSet, 0)
    SmallOverheadPushButtons ()
    DspShow ("BARO", "set")
end

function Baro_MODE_toggle ()
	if _tl("AB_MPL_Baro_STD", 0) then
        Baro_MODE_std ()
	else
        Baro_MODE_set ()
	end
end

function BARO_Unit_inHg ()
    ipc.log ("BARO inHg")
    LVarSet = "L:AB_MPL_Baro_Unit"
    ipc.writeLvar(LVarSet, 1)
    SmallOverheadPushButtons ()
    Altimeter_BARO_MODE_inHg ()
    DspShow ("Unit", "inHg")
end

function BARO_Unit_hPa ()
    ipc.log ("BARO hPa")
    LVarSet = "L:AB_MPL_Baro_Unit"
    ipc.writeLvar(LVarSet, 0)
    SmallOverheadPushButtons ()
    Altimeter_BARO_MODE_hPa ()
    DspShow ("Unit", "hPa")
end

function BARO_Unit_toggle ()
	if ipc.readLvar("AB_MPL_Baro_Unit") == 0 then
       BARO_Unit_inHg ()
	else
       BARO_Unit_hPa ()
	end
end

-- ## Other Main Panel #######

function Alarms_WARN_off ()
    ipc.writeLvar("L:AB_MPL_Master_Warning", 1)
    SmallOverheadPushButtons ()
end

function Alarms_CAUTION_off ()
    ipc.writeLvar("L:AB_MPL_Master_Caution", 1)
    SmallOverheadPushButtons ()
end

function Alarms_BOTH_off ()
	Alarms_WARN_off ()
    ipc.sleep(100)
	Alarms_CAUTION_off ()
end

function Chrono ()
   ipc.writeLvar("AB_MPL_CHRONO", 1)
   SmallOverheadPushButtons ()
end

function Autobrake_min ()
    LVarSet = "L:Autobrake_position"
    ipc.writeLvar(LVarSet, 2)
    SmallOverheadPushButtons ()
    DspShow ("ABRK", "min")
end

function Autobrake_med ()
    LVarSet = "L:Autobrake_position"
    ipc.writeLvar(LVarSet, 3)
    SmallOverheadPushButtons ()
    DspShow ("ABRK", "med")
end

function Autobrake_max ()
    LVarSet = "L:Autobrake_position"
    ipc.writeLvar(LVarSet, 0)
    SmallOverheadPushButtons ()
    DspShow ("ABRK", "max")
end

function Autobrake_off ()
    LVarSet = "L:Autobrake_position"
    ipc.writeLvar(LVarSet, 1)
    SmallOverheadPushButtons ()
    DspShow ("ABRK", "off")
end

function Autobrake_cycle ()
	auto_brk = auto_brk + 1
	if auto_brk > 4 then
        auto_brk = 1
    end
	if auto_brk == 1 then
		 Autobrake_min ()
	elseif auto_brk == 2 then
		Autobrake_med ()
	elseif auto_brk == 3 then
		Autobrake_max ()
	else
		Autobrake_off ()
	end
end

function Autobrake_inc ()
    ABRKvar = ipc.readLvar("L:Autobrake_position")
    if ABRKvar == 1 then
        Autobrake_min ()
    elseif ABRKvar == 2 then
        Autobrake_med ()
    elseif ABRKvar == 3 then
        Autobrake_max ()
    end
end

function Autobrake_dec ()
    ABRKvar = ipc.readLvar("L:Autobrake_position")
    if ABRKvar == 0 then
        Autobrake_med ()
    elseif ABRKvar == 3 then
        Autobrake_min ()
    elseif ABRKvar == 2 then
        Autobrake_off ()
    end
end

function AB_Brakefan_on ()
    ipc.writeLvar("L:AB_BRK_FAN", 1)
    SmallOverheadPushButtons ()
    DspShow ("BFan", "on")
end

function AB_Brakefan_off ()
    ipc.writeLvar("L:AB_BRK_FAN", 0)
    SmallOverheadPushButtons ()
    DspShow ("BFan", "off")
end

function AB_Brakefan_toggle ()
	if _tl("AB_BRK_FAN", 0) then
       AB_Brakefan_on ()
	else
       AB_Brakefan_off ()
	end
end

function AB_Antiskid_toggle ()
	_ANTISKID_BRAKES_TOGGLE ()
    NormalSwitch ()
    DspShow("Skid","Tog")
end

-- ## Clock Main Panel ###############

function AB_MPL_CLOCK_Chrono_start ()
   ipc.writeLvar("L:AB_MPL_CLOCK_Chrono_start", 1)
    SmallOverheadPushButtons ()
    DspShow ("CHR", "strt")
end

function AB_MPL_CLOCK_Chrono_stop ()
   ipc.writeLvar("L:AB_MPL_CLOCK_Chrono_start", 0)
    SmallOverheadPushButtons ()
    DspShow ("CHR", "stop")
end

function AB_MPL_CLOCK_Chrono_toggle ()
	if _tl("AB_MPL_CLOCK_Chrono_start", 0) then
        AB_MPL_CLOCK_Chrono_start ()
	else
        AB_MPL_CLOCK_Chrono_stop ()
	end
end

function AB_MPL_CLOCK_Chrono_reset ()
    ipc.writeLvar("L:AB_MPL_CLOCK_RST", 1)
    SmallOverheadPushButtons ()
    DspShow ("CHR", "rset")
end

-----

function AB_MPL_CLOCK_run ()
    ipc.writeLvar("AB_MPL_CLOCK_ET_SW", 0)
    DspShow ("CLCK", "run")
    ASC_KnobRotate ()
end

function AB_MPL_CLOCK_stp ()
    ipc.writeLvar("AB_MPL_CLOCK_ET_SW", 1)
    DspShow ("CLCK", "stp")
    ASC_KnobRotate ()
end

function AB_MPL_CLOCK_st ()
    ipc.writeLvar("AB_MPL_CLOCK_ET_SW", 2)
    DspShow ("CLCK", "st")
    ASC_KnobRotate ()
end

function AB_MPL_CLOCK_inc ()
    CLCK = ipc.readLvar("AB_MPL_CLOCK_ET_SW")
    if CLCK == 0 then AB_MPL_CLOCK_stp ()
    elseif CLCK == 1 then AB_MPL_CLOCK_st ()
    end
end

function AB_MPL_CLOCK_dec ()
    CLCK = ipc.readLvar("AB_MPL_CLOCK_ET_SW")
    if CLCK == 2 then
        AB_MPL_CLOCK_stp ()
    elseif CLCK == 1 then
        AB_MPL_CLOCK_run ()
    end
end

-- ## OVHD EXT LIGHTS ###################################

-- toggles all navigation/identification lights
function Lights_FLYING_toggle ()
	if _tl("Strobe_light", 0) then
		Lights_STROBE_auto ()
        Lights_BEACON_on ()
        Lights_WING_on ()
        Lights_NAV_LOGO_on ()
	else
		Lights_STROBE_off ()
        Lights_BEACON_off ()
        Lights_WING_off ()
        Lights_NAV_LOGO_off ()
    end
end

function Lights_LANDING_on ()
    LVarSet = "L:Landlight_switch"
	ipc.writeLvar(LVarSet, 2)
   	ipc.control(66059)
    LightSwitch ()
    DspShow ("LL", "on")
end

function Lights_LANDING_off ()
    LVarSet = "L:Landlight_switch"
    ipc.writeLvar(LVarSet, 1)
    ipc.control(66060)
    LightSwitch ()
    DspShow ("LL", "off")
end

function Lights_LANDING_retract ()
    Lights_LANDING_off ()
    _sleep(100,200)
    LVarSet = "L:Landlight_switch"
    ipc.writeLvar(LVarSet, 0)
    LightSwitch ()
    DspShow ("LL", "retr")
end

function Lights_LANDING_toggle ()
	if _tl("Landlight_switch", 0) then
		Lights_LANDING_on ()
	else
		Lights_LANDING_retract ()
	end
end

function Lights_TAXI_on ()
    LVarSet = "L:AB_TAXI_LT"
	ipc.writeLvar(LVarSet, 1)
    LightSwitch ()
    DspShow ("Taxi", "on")
end

function Lights_TAXI_takeoff ()
    LVarSet = "L:AB_TAXI_LT"
    ipc.writeLvar(LVarSet, 2)
    LightSwitch ()
    DspShow ("Taxi", "T/O")
end

function Lights_TAXI_off ()
    LVarSet = "L:AB_TAXI_LT"
    ipc.writeLvar(LVarSet, 0)
    LightSwitch ()
    DspShow ("Taxi", "off")
end

function Lights_TAXI_toggle ()
    LVarSet = "L:AB_TAXI_LT"
    if ipc.readLvar(LVarSet) == 0 then
        Lights_TAXI_on()
    elseif ipc.readLvar(LVarSet) == 1 then
        Lights_TAXI_takeoff()
    else
        Lights_TAXI_off()
    end
end

function Lights_RUNWAY_on ()
    LVarSet = "L:AB_OVH_LIGHTS_RWYTURNOFF"
    ipc.writeLvar(LVarSet, 1)
    LightSwitch ()
    DspShow ("RwyL", "on")
end

function Lights_RUNWAY_off ()
    LVarSet = "L:AB_OVH_LIGHTS_RWYTURNOFF"
    ipc.writeLvar(LVarSet, 0)
    LightSwitch ()
    DspShow ("RwyL", "off")
end

function Lights_RUNWAY_toggle ()
	if _tl("AB_OVH_LIGHTS_RWYTURNOFF", 0) then
		Lights_RUNWAY_on ()
	else
		Lights_RUNWAY_off ()
	end
end

function Lights_STROBE_on ()
    LVarSet = "L:Strobe_light"
    ipc.writeLvar(LVarSet, 2)
    LightSwitch ()
    DspShow ("STRB", "on")
end

function Lights_STROBE_auto ()
    LVarSet = "L:Strobe_light"
    ipc.writeLvar(LVarSet, 1)
    LightSwitch ()
    DspShow ("STRB", "auto")
end

function Lights_STROBE_off ()
    LVarSet = "L:Strobe_light"
    ipc.writeLvar(LVarSet, 0)
    LightSwitch ()
    DspShow ("STRB", "off")
end

function Lights_STROBE_toggle ()
    LVarSet = "L:Strobe_Light"
    if ipc.readLvar(LVarSet) == 0 then
        Lights_STROBE_auto()
    elseif ipc.readLvar(LVarSet) == 1 then
        Lights_STROBE_on()
    else
        Lights_STROBE_off()
    end
end

function Lights_BEACON_on ()
    LVarSet = "L:LIGHT_BEACON"
    ipc.writeLvar(LVarSet, 1)
    LightSwitch ()
	DspShow ("BCN", "on")
end

function Lights_BEACON_off ()
    LVarSet = "L:LIGHT_BEACON"
    ipc.writeLvar(LVarSet, 0)
    LightSwitch ()
	DspShow ("BCN", "off")
end

function Lights_BEACON_toggle ()
    if _tl("LIGHT_BEACON", 0) then
		Lights_BEACON_on ()
	else
		Lights_BEACON_off ()
	end
end

function Lights_NAV_LOGO_on ()
    if logic.And(ipc.readUW("0D0C"), 1) == 0 then
        ipc.control(66379)
    end
    LightSwitch ()
	DspShow ("NAV", "on")
end

function Lights_NAV_LOGO_off ()
    if logic.And(ipc.readUW("0D0C"), 1) == 1 then
        ipc.control(66379)
    end
    LightSwitch ()
	DspShow ("NAV", "off")
end

function Lights_NAV_LOGO_toggle ()
    if logic.And(ipc.readUW("0D0C"), 1) == 1 then
		Lights_NAV_LOGO_off ()
	else
		Lights_NAV_LOGO_on ()
	end
end

function Lights_WING_on ()
    if logic.And(ipc.readUW("0D0C"), 128) == 0 then
        ipc.control(66378)
    end
    LightSwitch ()
	DspShow ("WING", "on")
end

function Lights_WING_off ()
    if logic.And(ipc.readUW("0D0C"), 128) == 128 then
        ipc.control(66378)
    end
    LightSwitch ()
    DspShow ("WING", "off")
end

function Lights_WING_toggle ()
    if logic.And(ipc.readUW("0D0C"), 128) == 128 then
		Lights_WING_off ()
	else
		Lights_WING_on ()
	end
end

-- ## OVHD INT Lights ###################################

function Sign_CABINCREW_on()
    Sign_SEATBELTS_on()
    Sign_NOSMOKING_on()
    Lights_EMER_armed()
end

function Sign_CABINCREW_off()
    Sign_SEATBELTS_off()
    Sign_NOSMOKING_on()
    Lights_EMER_off()
end

function Sign_CABINCREW_toggle()
	if _tl("AB_OVH_SEATBELT", 0) then
        Sign_CABINCREW_on()
    else
        Sign_CABINCREW_off()
    end
end

function Lights_PANEL_on ()
    ipc.control(66056)
    LightSwitch ()
    DspShow ("PANL", "on")
end

function Lights_PANEL_off ()
    ipc.control(66057)
    LightSwitch ()
	DspShow ("PANL", "off")
end

function Lights_PANEL_set ()
    if logic.And(ipc.readUW("0D0C"), 32) == 32 then
        return true
    else
        return false
    end
end

function Lights_PANEL_toggle ()
    ipc.control(65750)
    LightSwitch ()
    if Lights_PANEL_set() then
        DspShow ("PANL", "off")
	else
        DspShow ("PANL", "on")
	end
 end

function Lights_DOME_set ()
    if logic.And(ipc.readUW("0D0C"), 512) == 512 then
        return true
    else
        return false
    end
end

function Lights_DOME_toggle ()
    ipc.control(66579)
    LightSwitch ()
    if Lights_DOME_set() then
        DspShow ("DOME", "off")
	else
        DspShow ("DOME", "on")
	end
end

function Lights_CABIN_on ()
    Lights_DOME_toggle ()
--	ipc.setbitsUW("0D0C", 512)
--	DspShow ("FLOD", "on")
--    LightSwitch ()
end

function Lights_CABIN_off ()
    Lights_DOME_toggle ()
--	ipc.clearbitsUW("0D0C", 512)
--	DspShow ("FLOD", "off")
--    LightSwitch ()
end

function Lights_CABIN_toggle ()
    if logic.And(ipc.readUW("0D0C"), 512) == 512 then
		Lights_CABIN_off ()
	else
		Lights_CABIN_on ()
	end
end

function Sign_SEATBELTS_on ()
    LVarSet = "L:AB_OVH_SEATBELT"
	ipc.writeLvar(LVarSet, 50)
    LightSwitch ()
    ipc.writeSB(0x341D, 1)
    DspShow ("Seat", "on")
end

function Sign_SEATBELTS_off ()
    LVarSet = "L:AB_OVH_SEATBELT"
    ipc.writeLvar(LVarSet, 0)
	ipc.writeLvar("L:ASC_NOSMOKE-SEATBELTS", 1)
    LightSwitch ()
    ipc.writeSB(0x341D, 0)
    DspShow ("Seat", "off")
end

function Sign_SEATBELTS_auto ()
    LVarSet = "L:AB_OVH_SEATBELT"
	ipc.writeLvar(LVarSet, 25)
	ipc.writeLvar("L:ASC_NOSMOKE-SEATBELTS", 1)
    LightSwitch ()
    DspShow ("Seat", "auto")
end

function Sign_SEATBELTS_toggle ()
	if _tl("AB_OVH_SEATBELT", 0) then
		Sign_SEATBELTS_on ()
	else
		Sign_SEATBELTS_off ()
	end
end

function Sign_NOSMOKING_on ()
    LVarSet = "L:AB_OVH_NO_SMOKING"
	ipc.writeLvar(LVarSet, 50)
    LightSwitch ()
    DspShow ("Smke", "on")
end

function Sign_NOSMOKING_off ()
    LVarSet = "L:AB_OVH_NO_SMOKING"
    ipc.writeLvar(LVarSet, -1)
	ipc.writeLvar("L:ASC_NOSMOKE-SEATBELTS", 1)
    LightSwitch ()
    DspShow ("Smke", "off")
end

function Sign_NOSMOKING_auto ()
    LVarSet = "L:AB_OVH_NO_SMOKING"
	ipc.writeLvar(LVarSet, 25)
	ipc.writeLvar("L:ASC_NOSMOKE-SEATBELTS", 1)
    LightSwitch ()
    DspShow ("Smke", "auto")
end

function Sign_NOSMOKING_toggle ()
	if _tl("AB_OVH_NO_SMOKING", 0) then
		Sign_NOSMOKING_on ()
	else
		Sign_NOSMOKING_off ()
	end
end

function Lights_EMER_on ()
    LVarSet = "L:AB_OVH_EMER_LT"
	ipc.writeLvar(LVarSet, 50)
    LightSwitch ()
    DspShow ("Emer", "on")
end

function Lights_EMER_off ()
    LVarSet = "L:AB_OVH_EMER_LT"
    ipc.writeLvar(LVarSet, 0)
    LightSwitch ()
    DspShow ("Emer", "off")
end

function Lights_EMER_armed ()
    LVarSet = "L:AB_OVH_EMER_LT"
	ipc.writeLvar(LVarSet, 25)
    LightSwitch ()
    DspShow ("Emer", "armd")
end

function Lights_EMER_toggle ()
	if _tl("AB_OVH_EMER_LT", 0) then
		Lights_EMER_armed ()
	else
		Lights_EMER_off ()
	end
end

function AB_ANN_LIGHTS_TEST_on ()
    ipc.writeLvar("AB_OVH_LIGHTS_ANN_TEST", 1)
    ipc.writeLvar("LightTest", 1)
    LightSwitch ()
    DspShow ("Test", "on")
end

function AB_ANN_LIGHTS_TEST_off ()
    ipc.writeLvar("AB_OVH_LIGHTS_ANN_TEST", 0)
    ipc.writeLvar("LightTest", 0)
    LightSwitch ()
    DspShow ("Test", "off")
end

function AB_ANN_LIGHTS_TEST_toggle ()
	if _tl("AB_OVH_LIGHTS_ANN_TEST", 0) then
       AB_ANN_LIGHTS_TEST_on ()
	else
       AB_ANN_LIGHTS_TEST_off ()
	end
end


-- ## OVHD Anti ICE ###############

function AB_AntiIce_WING_on ()
   ipc.writeLvar("AB_OVH_ANTIICE_WING", 1)
   SmallOverheadPushButtons ()
   DspShow ("WIce", "on")
end

function AB_AntiIce_WING_off ()
   ipc.writeLvar("AB_OVH_ANTIICE_WING", 0)
   SmallOverheadPushButtons ()
   DspShow ("WIce", "off")
end

function AB_AntiIce_WING_toggle ()
	if _tl("AB_OVH_ANTIICE_WING", 0) then
       AB_AntiIce_WING_on ()
	else
       AB_AntiIce_WING_off ()
	end
end

function AB_AntiIce_ENGL_on ()
   ipc.writeLvar("AB_OVH_ANTIICE_ENGL", 1)
   SmallOverheadPushButtons ()
   DspShow ("LIce", "on")
end

function AB_AntiIce_ENGL_off ()
   ipc.writeLvar("AB_OVH_ANTIICE_ENGL", 0)
   SmallOverheadPushButtons ()
   DspShow ("LIce", "off")
end

function AB_AntiIce_ENGL_toggle ()
	if _tl("AB_OVH_ANTIICE_ENGL", 0) then
       AB_AntiIce_ENGL_on ()
	else
       AB_AntiIce_ENGL_off ()
	end
end

function AB_AntiIce_ENGR_on ()
   ipc.writeLvar("AB_OVH_ANTIICE_ENGR", 1)
   SmallOverheadPushButtons ()
   DspShow ("RIce", "on")
end

function AB_AntiIce_ENGR_off ()
   ipc.writeLvar("AB_OVH_ANTIICE_ENGR", 0)
   SmallOverheadPushButtons ()
   DspShow ("RIce", "off")
end

function AB_AntiIce_ENGR_toggle ()
	if _tl("AB_OVH_ANTIICE_ENGR", 0) then
       AB_AntiIce_ENGR_on ()
	else
       AB_AntiIce_ENGR_off ()
	end
end

function AB_AntiIce_ENG_both_on ()
    AB_AntiIce_ENGL_on ()
    _sleep(100,500)
    AB_AntiIce_ENGR_on ()
end

function AB_AntiIce_ENG_both_off ()
    AB_AntiIce_ENGL_off ()
    _sleep(100,500)
    AB_AntiIce_ENGR_off ()
end

function AB_AntiIce_ENG_both_toggle ()
    AB_AntiIce_ENGL_toggle ()
    _sleep(100,500)
    AB_AntiIce_ENGR_toggle ()
end

function AB_AntiIce_PROBEWINDOW_on ()
   ipc.writeLvar("AB_OVH_ANTIICE_PROBEWINDOW", 1)
   SmallOverheadPushButtons ()
   DspShow ("RIce", "on")
end

function AB_AntiIce_PROBEWINDOW_off ()
   ipc.writeLvar("AB_OVH_ANTIICE_PROBEWINDOW", 0)
   SmallOverheadPushButtons ()
   DspShow ("RIce", "off")
end

function AB_AntiIce_PROBEWINDOW_toggle ()
	if _tl("AB_OVH_ANTIICE_PROBEWINDOW", 0) then
       AB_AntiIce_PROBEWINDOW_on ()
	else
       AB_AntiIce_PROBEWINDOW_off ()
	end
end


-- ## OVHD Air Cond ###############

function Pack1_on ()
    LVarSet = "L:AB_OVH_PNEUPACKL"
    ipc.writeLvar(LVarSet, 1)
    SmallOverheadPushButtons ()
    DspShow ("PAK1", "on")
end

function Pack1_off ()
    LVarSet = "L:AB_OVH_PNEUPACKL"
    ipc.writeLvar(LVarSet, 0)
    SmallOverheadPushButtons ()
    DspShow ("PAK1", "off")
end

function Pack1_toggle ()
	if _tl("AB_OVH_PNEUPACKL", 0) then
		Pack1_on ()
	else
		Pack1_off ()
	end
end

function Pack2_on ()
    LVarSet = "L:AB_OVH_PNEUPACKR"
    ipc.writeLvar(LVarSet, 1)
    SmallOverheadPushButtons ()
    DspShow ("PAK2", "on")
end

function Pack2_off ()
    LVarSet = "L:AB_OVH_PNEUPACKR"
    ipc.writeLvar(LVarSet, 0)
    SmallOverheadPushButtons ()
    DspShow ("PAK2", "off")
end

function Pack2_toggle ()
	if _tl("AB_OVH_PNEUPACKR", 0) then
		Pack2_on ()
	else
		Pack2_off ()
	end
end

function Pack_BOTH_on ()
	Pack1_on ()
    _sleep(100,200)
	Pack2_on ()
end

function Pack_BOTH_off ()
	Pack1_off ()
    _sleep(100,200)
	Pack2_off ()
end

function Pack_BOTH_toggle ()
	if _t("PackBOTH") then
		Pack_BOTH_on ()
	else
		Pack_BOTH_off ()
	end
end

-----

function Eng1_Bleed_on ()
    LVarSet = "L:AB_OVH_PNEUBLEEDL"
    ipc.writeLvar(LVarSet, 1)
    SmallOverheadPushButtons ()
    DspShow ("BLD1", "on")
end

function Eng1_Bleed_off ()
    LVarSet = "L:AB_OVH_PNEUBLEEDL"
    ipc.writeLvar(LVarSet, 0)
    SmallOverheadPushButtons ()
    DspShow ("BLD1", "off")
end

function Eng1_Bleed_toggle ()
	if _tl("AB_OVH_PNEUBLEEDL", 0) then
		Eng1_Bleed_on ()
	else
		Eng1_Bleed_off ()
	end
end

function Eng2_Bleed_on ()
    LVarSet = "L:AB_OVH_PNEUBLEEDR"
    ipc.writeLvar(LVarSet, 1)
    SmallOverheadPushButtons ()
    DspShow ("BLD2", "on")
end

function Eng2_Bleed_off ()
    LVarSet = "L:AB_OVH_PNEUBLEEDR"
    ipc.writeLvar(LVarSet, 0)
    SmallOverheadPushButtons ()
    DspShow ("BLD2", "off")
end

function Eng2_Bleed_toggle ()
	if _tl("AB_OVH_PNEUBLEEDR", 0) then
		Eng2_Bleed_on ()
	else
		Eng2_Bleed_off ()
	end
end

function Eng_Bleed_BOTH_on ()
	Eng1_Bleed_on ()
    _sleep(100,200)
	Eng2_Bleed_on ()
end

function Eng_Bleed_BOTH_off ()
	Eng1_Bleed_off ()
    _sleep(100,200)
	Eng2_Bleed_off ()
end

function Eng_Bleed_BOTH_toggle ()
	if _t("Eng_BleedBOTH") then
		Eng_Bleed_BOTH_on ()
	else
		Eng_Bleed_BOTH_off ()
	end
end

function Ovhd_HotAir_on ()
    LVarSet = "L:AB_OVH_HOTAIR"
    ipc.writeLvar(LVarSet, 1)
    SmallOverheadPushButtons ()
    DspShow ("HotA", "on")
end

function Ovhd_HotAir_off ()
    LVarSet = "L:AB_OVH_HOTAIR"
    ipc.writeLvar(LVarSet, 0)
    SmallOverheadPushButtons ()
    DspShow ("HotA", "off")
end

function Ovhd_HotAir_toggle ()
	if _tl("AB_OVH_HOTAIR", 0) then
		Ovhd_HotAir_on ()
	else
		Ovhd_HotAir_off ()
	end
end

function Pack_Flow_norm ()
    ipc.writeLvar("AB_OVH_PACKFLOWCTR", 1)
    LightSwitch ()
    DspShow ("PakF", "norm")
end

function Pack_Flow_low ()
    ipc.writeLvar("AB_OVH_PACKFLOWCTR", 0)
    LightSwitch ()
    DspShow ("PakF", "low")
end

function Pack_Flow_high ()
    ipc.writeLvar("AB_OVH_PACKFLOWCTR", 2)
    LightSwitch ()
    DspShow ("PakF", "high")
end

function Pack_Flow_inc ()
    PakF = ipc.readLvar("AB_OVH_PACKFLOWCTR")
    if PakF == 0 then Pack_Flow_norm ()
    elseif PakF == 1 then Pack_Flow_high ()
    end
end

function Pack_Flow_dec ()
    PakF = ipc.readLvar("AB_OVH_PACKFLOWCTR")
    if PakF == 2 then Pack_Flow_norm ()
    elseif PakF == 1 then Pack_Flow_low ()
    end
end

-----

function X_Bleed_auto ()
    ipc.writeLvar("AB_OVH_PNEUXBLEED", 1)
    LightSwitch ()
    DspShow ("XBld", "auto")
end

function X_Bleed_shut ()
    ipc.writeLvar("AB_OVH_PNEUXBLEED", 0)
    LightSwitch ()
    DspShow ("XBld", "shut")
end

function X_Bleed_open ()
    ipc.writeLvar("AB_OVH_PNEUXBLEED", 2)
    LightSwitch ()
    DspShow ("XBld", "open")
end

function X_Bleed_inc ()
    XBld = ipc.readLvar("AB_OVH_PNEUXBLEED")
    if XBld == 0 then X_Bleed_auto ()
    elseif XBld == 1 then X_Bleed_open ()
    end
end

function X_Bleed_dec ()
    XBld = ipc.readLvar("AB_OVH_PNEUXBLEED")
    if XBld == 2 then X_Bleed_auto ()
    elseif XBld == 1 then X_Bleed_shut ()
    end
end

---------

function ZoneTemp_Cockpit_inc ()
   ZT1 = ipc.readLvar("AB_OVH_ZONETEMP1")
   if ZT1 <= 29.75 then
   ZT1 = ZT1 + 0.25
   else ZT1 = 30
   end
   ipc.writeLvar("AB_OVH_ZONETEMP1", ZT1)
   DspShow ("Temp", ZT1.." C")
end

function ZoneTemp_Cockpit_dec ()
   ZT1 = ipc.readLvar("AB_OVH_ZONETEMP1")

   if ZT1 >= 20.25 then
   ZT1 = ZT1 - 0.25
   else ZT1 = 20
   end
   ipc.writeLvar("AB_OVH_ZONETEMP1", ZT1)
   DspShow ("Temp", ZT1.." C")
end

function ZoneTemp_Cockpit_incfast ()
   ZT1 = ipc.readLvar("AB_OVH_ZONETEMP1")

   if ZT1 <= 29 then
   ZT1 = ZT1 + 1
   else ZT1 = 30
   end
   ipc.writeLvar("AB_OVH_ZONETEMP1", ZT1)
   DspShow ("Temp", ZT1.." C")
end

function ZoneTemp_Cockpit_decfast ()
   ZT1 = ipc.readLvar("AB_OVH_ZONETEMP1")

   if ZT1 >= 21 then
   ZT1 = ZT1 - 1
   else ZT1 = 20
   end
   ipc.writeLvar("AB_OVH_ZONETEMP1", ZT1)
   DspShow ("Temp", ZT1.." C")
end

function ZoneTemp_FwdCabin_inc ()
   ZT2 = ipc.readLvar("AB_OVH_ZONETEMP2")

   if ZT2 <= 29.75 then
   ZT2 = ZT2 + 0.25
   else ZT2 = 30
   end
   ipc.writeLvar("AB_OVH_ZONETEMP2", ZT2)
   DspShow ("Temp", ZT2.." C")
end

function ZoneTemp_FwdCabin_dec ()
   ZT2 = ipc.readLvar("AB_OVH_ZONETEMP2")

   if ZT2 >= 20.25 then
   ZT2 = ZT2 - 0.25
   else ZT2 = 20
   end
   ipc.writeLvar("AB_OVH_ZONETEMP2", ZT2)
   DspShow ("Temp", ZT2.." C")
end

function ZoneTemp_FwdCabin_incfast ()
   ZT2 = ipc.readLvar("AB_OVH_ZONETEMP2")

   if ZT2 <= 29 then
   ZT2 = ZT2 + 1
   else ZT2 = 30
   end
   ipc.writeLvar("AB_OVH_ZONETEMP2", ZT2)
   DspShow ("Temp", ZT2.." C")
end

function ZoneTemp_FwdCabin_decfast ()
   ZT2 = ipc.readLvar("AB_OVH_ZONETEMP2")

   if ZT2 >= 21 then
   ZT2 = ZT2 - 1
   else ZT2 = 20
   end
   ipc.writeLvar("AB_OVH_ZONETEMP2", ZT2)
   DspShow ("Temp", ZT2.." C")
end

function ZoneTemp_AftCabin_inc ()
   ZT3 = ipc.readLvar("AB_OVH_ZONETEMP3")

   if ZT3 <= 29.75 then
   ZT3 = ZT3 + 0.25
   else ZT3 = 30
   end
   ipc.writeLvar("AB_OVH_ZONETEMP3", ZT3)
   DspShow ("Temp", ZT3.." C")
end

function ZoneTemp_AftCabin_dec ()
   ZT3 = ipc.readLvar("AB_OVH_ZONETEMP3")

   if ZT3 >= 20.25 then
   ZT3 = ZT3 - 0.25
   else ZT3 = 20
   end
   ipc.writeLvar("AB_OVH_ZONETEMP3", ZT3)
   DspShow ("Temp", ZT3.." C")
end

function ZoneTemp_AftCabin_incfast ()
   ZT3 = ipc.readLvar("AB_OVH_ZONETEMP3")

   if ZT3 <= 29 then
   ZT3 = ZT3 + 1
   else ZT3 = 30
   end
   ipc.writeLvar("AB_OVH_ZONETEMP3", ZT3)
   DspShow ("Temp", ZT3.." C")
end

function ZoneTemp_AftCabin_decfast ()
   ZT3 = ipc.readLvar("AB_OVH_ZONETEMP3")

   if ZT3 >= 21 then
   ZT3 = ZT3 - 1
   else ZT3 = 20
   end
   ipc.writeLvar("AB_OVH_ZONETEMP3", ZT3)
   DspShow ("Temp", ZT3.." C")
end


-- ## OVHD ELEC and APU ########

function Battery1_on ()
    LVarSet = "L:AB_OVH_ELECBAT1"
    ipc.writeLvar(LVarSet, 1)
    SmallOverheadPushButtons ()
    DspShow ("BAT1", "on")
end

function Battery1_off ()
    LVarSet = "L:AB_OVH_ELECBAT1"
    ipc.writeLvar(LVarSet, 0)
    SmallOverheadPushButtons ()
    DspShow ("BAT1", "off")
end

function Battery1_toggle ()
	if _tl("AB_OVH_ELECBAT1", 0) then
		Battery1_on ()
	else
		Battery1_off ()
	end
end

function Battery2_on ()
    LVarSet = "L:AB_OVH_ELECBAT2"
    ipc.writeLvar(LVarSet, 1)
    SmallOverheadPushButtons ()
    DspShow ("BAT2", "on")
end

function Battery2_off ()
    LVarSet = "L:AB_OVH_ELECBAT2"
    ipc.writeLvar(LVarSet, 0)
    SmallOverheadPushButtons ()
    DspShow ("BAT2", "off")
end

function Battery2_toggle ()
	if _tl("AB_OVH_ELECBAT2", 0) then
		Battery2_on ()
	else
		Battery2_off ()
	end
end

function Battery_BOTH_on ()
	Battery1_on ()
    _sleep(100,200)
	Battery2_on ()
end

function Battery_BOTH_off ()
	Battery1_off ()
    _sleep(100,200)
	Battery2_off ()
end

function Battery_BOTH_toggle ()
	if _t("BATBOTH") then
		Battery_BOTH_on ()
	else
		Battery_BOTH_off ()
	end
end

----

function GEN1_on ()
    LVarSet = "L:AB_OVH_ELECGENL"
    ipc.writeLvar(LVarSet, 1)
    SmallOverheadPushButtons ()
    DspShow ("GEN1", "on")
end

function GEN1_off ()
    LVarSet = "L:AB_OVH_ELECGENL"
    ipc.writeLvar(LVarSet, 0)
    SmallOverheadPushButtons ()
    DspShow ("GEN1", "off")
end

function GEN1_toggle ()
	if _tl("AB_OVH_ELECGENL", 0) then
		GEN1_on ()
	else
		GEN1_off ()
	end
end

function GEN2_on ()
    LVarSet = "L:AB_OVH_ELECGENR"
    ipc.writeLvar(LVarSet, 1)
    SmallOverheadPushButtons ()
    DspShow ("GEN2", "on")
end

function GEN2_off ()
    LVarSet = "L:AB_OVH_ELECGENR"
    ipc.writeLvar(LVarSet, 0)
    SmallOverheadPushButtons ()
    DspShow ("GEN2", "off")
end

function GEN2_toggle ()
	if _tl("AB_OVH_ELECGENR", 0) then
		GEN2_on ()
	else
		GEN2_off ()
	end
end

function GEN_BOTH_on ()
	GEN1_on ()
    _sleep(100,200)
	GEN2_on ()
end

function GEN_BOTH_off ()
	GEN1_off ()
    _sleep(100,200)
	GEN2_off ()
end

function GEN_BOTH_toggle ()
	if _t("GENBOTH") then
		GEN_BOTH_on ()
	else
		GEN_BOTH_off ()
	end
end

---

function BUS_TIE_on ()
    LVarSet = "L:AB_OVH_ELECBT"
    ipc.writeLvar(LVarSet, 1)
    SmallOverheadPushButtons ()
    DspShow ("BUS", "on")
end

function BUS_TIE_off ()
    LVarSet = "L:AB_OVH_ELECBT"
    ipc.writeLvar(LVarSet, 0)
    SmallOverheadPushButtons ()
    DspShow ("BUS", "off")
end

function BUS_TIE_toggle ()
	if _tl("AB_OVH_ELECBT", 0) then
		BUS_TIE_on ()
	else
		BUS_TIE_off ()
	end
end

----

function AC_ESS_FEED_on ()
    LVarSet = "L:AB_OVH_AC_ESS_FEED"
    ipc.writeLvar(LVarSet, 1)
    SmallOverheadPushButtons ()
    DspShow ("FEED", "on")
end

function AC_ESS_FEED_off ()
    LVarSet = "L:AB_OVH_AC_ESS_FEED"
    ipc.writeLvar(LVarSet, 0)
    SmallOverheadPushButtons ()
    DspShow ("FEED", "off")
end

function AC_ESS_FEED_toggle ()
	if _tl("AB_OVH_AC_ESS_FEED", 0) then
		AC_ESS_FEED_on ()
	else
		AC_ESS_FEED_off ()
	end
end

---

function EXT_PWR_on ()
    LVarSet = "L:AB_OVH_ELECEXT"
    ExtPAvail = ipc.readLvar("AB_OVH_ELECEXT_ON")
    ExtPAvail2 = ipc.readLvar("AB_OVH_ELECEXT_AVAIL2")
    if ExtPAvail == 0 and ExtPAvail2 == 0 then
        DspShow ("!Ext", "!Pwr")
        ipc.sleep(1500)
        DspShow ("not", "avlb")
        ipc.sleep(1500)
    else
        ipc.writeLvar(LVarSet, 1)
        SmallOverheadPushButtons ()
        DspShow ("ExtP", "on")
    end
end

function EXT_PWR_off ()
    LVarSet = "L:AB_OVH_ELECEXT"
    ipc.writeLvar(LVarSet, 0)
    SmallOverheadPushButtons ()
    DspShow ("ExtP", "off")
end

function EXT_PWR_toggle ()
	if _tl("AB_OVH_ELECEXT", 0) then
		EXT_PWR_on ()
	else
		EXT_PWR_off ()
	end
end

function IDG1_Cover_open ()
    LVarSet = "L:AB_OVH_IDG1_COVER"
    ipc.writeLvar(LVarSet, 1)
end

function IDG1_Cover_close ()
    LVarSet = "L:AB_OVH_IDG1_COVER"
    ipc.writeLvar(LVarSet, 0)
end

function IDG1_Cover_toggle ()
	if _tl("AB_OVH_IDG1_COVER", 0) then
		IDG1_Cover_open ()
	else
		IDG1_Cover_close ()
	end
end

function IDG2_Cover_open ()
    LVarSet = "L:AB_OVH_IDG2_COVER"
    ipc.writeLvar(LVarSet, 1)
end

function IDG2_Cover_close ()
    LVarSet = "L:AB_OVH_IDG2_COVER"
    ipc.writeLvar(LVarSet, 0)
end

function IDG2_Cover_toggle ()
	if _tl("AB_OVH_IDG2_COVER", 0) then
		IDG2_Cover_open ()
	else
		IDG2_Cover_close ()
	end
end

----

function IDG1_push ()
    IDG1_Cover_open ()
    _sleep(300,600)
    LVarSet = "L:AB_OVH_IDG1"
    ipc.writeLvar(LVarSet, 1)
    SmallOverheadPushButtons ()
    DspShow ("IDG1", "disc")
end

function IDG2_push ()
    IDG2_Cover_open ()
    _sleep(300,600)
    LVarSet = "L:AB_OVH_IDG2"
    ipc.writeLvar(LVarSet, 1)
    SmallOverheadPushButtons ()
    DspShow ("IDG2", "disc")
end

---

function APU_MASTER_on ()
    LVarSet = "AB_OVH_APU_MASTER"
    ipc.writeLvar(LVarSet, 1)
    SmallOverheadPushButtons ()
    DspShow ("APU", "on")
end

function APU_MASTER_off ()
    LVarSet = "AB_OVH_APU_MASTER"
    ipc.writeLvar(LVarSet, 0)
    SmallOverheadPushButtons ()
    APU_BLEED_off ()
    APU_START_off ()
    DspShow ("APU", "off")
end

function APU_MASTER_toggle ()
	if _tl("AB_OVH_APU_MASTER", 0) then
		APU_MASTER_on ()
	else
		APU_MASTER_off ()
	end
end

function APU_START_on ()
    LVarSet = "AB_OVH_APU_Start"
    if ipc.readLvar("AB_OVH_APU_MASTER") == 1 then
        ipc.writeLvar(LVarSet, 1)
        SmallOverheadPushButtons ()
        DspShow ("APU", "strt")
    else
        ipc.writeLvar(LVarSet, 0)
    end
end

function APU_START_off ()
    LVarSet = "AB_OVH_APU_Start"
    ipc.writeLvar(LVarSet, 0)
    SmallOverheadPushButtons ()
    DspShow ("APU", "Soff")
end

function APU_START_toggle ()
	if _tl("AB_OVH_APU_Start", 0) then
		APU_START_on ()
	else
		APU_START_off ()
	end
end

function APU_BLEED_on ()
    if ipc.readLvar("AB_OVH_APU_MASTER") == 1 and
        ipc.readLvar("AB_OVH_APU_START_LIGHT_AVAIL") == 1 then
        LVarSet = "L:AB_OVH_PNEUBLEEDAPU"
        ipc.writeLvar(LVarSet, 1)
        SmallOverheadPushButtons ()
        DspShow ("APU", "bled")
    else
        LVarSet = "L:AB_OVH_PNEUBLEEDAPU"
        ipc.writeLvar(LVarSet, 0)
    end
end

function APU_BLEED_off ()
    LVarSet = "L:AB_OVH_PNEUBLEEDAPU"
    ipc.writeLvar(LVarSet, 0)
    SmallOverheadPushButtons ()
    DspShow ("APU", "Boff")
end

function APU_BLEED_toggle ()
	if _tl("AB_OVH_PNEUBLEEDAPU", 0) then
		APU_BLEED_on ()
	else
		APU_BLEED_off ()
	end
end

function APU_GEN_on ()
    LVarSet = "L:AB_OVH_ELECGENAPU"
    ipc.writeLvar(LVarSet, 1)
    SmallOverheadPushButtons ()
    DspShow ("APU", "Gen")
end

function APU_GEN_off ()
    LVarSet = "L:AB_OVH_ELECGENAPU"
    ipc.writeLvar(LVarSet, 0)
    SmallOverheadPushButtons ()
    DspShow ("APU", "Goff")
end

function APU_GEN_toggle ()
	if _tl("AB_OVH_ELECGENAPU", 0) then
		APU_GEN_on ()
	else
		APU_GEN_off ()
	end
end

function APU_Master_Start_on ()
    APU_MASTER_on ()
    _sleep(200, 600)
    APU_START_on ()
end

function APU_Master_Start_off ()
    APU_START_off ()
    _sleep(200, 600)
    APU_MASTER_off ()
end

function APU_Master_Start_toggle ()
	if _tl("APUMasterStart",0) then
       APU_Master_Start_on ()
	else
       APU_Master_Start_off ()
	end
end

function APU_Master_Start_Bleed_on ()
    APU_MASTER_on ()
    _sleep(200, 600)
    APU_START_on ()
    _sleep(200, 600)
    APU_BLEED_on ()
end

function APU_Master_Start_Bleed_off ()
    APU_BLEED_off ()
    _sleep(200, 600)
    APU_START_off ()
    _sleep(200, 600)
    APU_MASTER_off ()
end

function APU_Master_Start_Bleed_toggle ()
	if _tl("APUMasterStartBleed",1) then
       APU_Master_Start_Bleed_on ()
	else
       APU_Master_Start_Bleed_off ()
	end
end

-- ## OVHD Fuel  ###############

function FuelPump_L_1_on ()
    ipc.writeLvar("L:AB_OVH_FUELPL1", 1)
    SmallOverheadPushButtons ()
    DspShow ("PmpL", "1 on")
end

function FuelPump_L_1_off ()
    ipc.writeLvar("L:AB_OVH_FUELPL1", 0)
    SmallOverheadPushButtons ()
    DspShow ("PmpL", "1off")
end

function FuelPump_L_1_toggle ()
	if _tl("AB_OVH_FUELPL1", 0) then
		FuelPump_L_1_on ()
	else
		FuelPump_L_1_off ()
	end
end

function FuelPump_L_2_on ()
    ipc.writeLvar("L:AB_OVH_FUELPL2", 1)
    SmallOverheadPushButtons ()
    DspShow ("PmpL", "2 on")
end

function FuelPump_L_2_off ()
    ipc.writeLvar("L:AB_OVH_FUELPL2", 0)
    SmallOverheadPushButtons ()
    DspShow ("PmpL", "2off")
end

function FuelPump_L_2_toggle ()

	if _tl("AB_OVH_FUELPL2", 0) then
		FuelPump_L_2_on ()
	else
		FuelPump_L_2_off ()
	end
end

function FuelPump_L_BOTH_on ()
    FuelPump_L_1_on ()
    _sleep(100,250)
    FuelPump_L_2_on ()
end

function FuelPump_L_BOTH_off ()
    FuelPump_L_1_off ()
    _sleep(100,250)
    FuelPump_L_2_off ()
end

function FuelPump_L_BOTH_toggle ()
	if _t("FuelPump_LBOTH") then
		FuelPump_L_BOTH_on ()
	else
		FuelPump_L_BOTH_off ()
	end
end

---------

function FuelPump_C_1_on ()
    ipc.writeLvar("L:AB_OVH_FUELPCL", 1)
    SmallOverheadPushButtons ()
    DspShow ("PmpC", "1 on")
end

function FuelPump_C_1_off ()
    ipc.writeLvar("L:AB_OVH_FUELPCL", 0)
    SmallOverheadPushButtons ()
    DspShow ("PmpC", "1off")
end

function FuelPump_C_1_toggle ()
	if _tl("AB_OVH_FUELPCL", 0) then
		FuelPump_C_1_on ()
	else
		FuelPump_C_1_off ()
	end
end

function FuelPump_C_2_on ()
    ipc.writeLvar("L:AB_OVH_FUELPCR", 1)
    SmallOverheadPushButtons ()
    DspShow ("PmpC", "2 on")
end

function FuelPump_C_2_off ()
    ipc.writeLvar("L:AB_OVH_FUELPCR", 0)
    SmallOverheadPushButtons ()
    DspShow ("PmpC", "2off")
end

function FuelPump_C_2_toggle ()
	if _tl("AB_OVH_FUELPCR", 0) then
		FuelPump_C_2_on ()
	else
		FuelPump_C_2_off ()
	end
end

function FuelPump_C_BOTH_on ()
    FuelPump_C_1_on ()
    _sleep(100,250)
    FuelPump_C_2_on ()
end

function FuelPump_C_BOTH_off ()
    FuelPump_C_1_off ()
    _sleep(100,250)
    FuelPump_C_2_off ()
end

function FuelPump_C_BOTH_toggle ()
	if _t("FuelPump_CBOTH") then
		FuelPump_C_BOTH_on ()
	else
		FuelPump_C_BOTH_off ()
	end
end

function FuelPump_R_1_on ()
    ipc.writeLvar("L:AB_OVH_FUELPR1", 1)
    SmallOverheadPushButtons ()
    DspShow ("PmpR", "1 on")
end

function FuelPump_R_1_off ()
    ipc.writeLvar("L:AB_OVH_FUELPR1", 0)
    SmallOverheadPushButtons ()
    DspShow ("PmpR", "1off")
end

function FuelPump_R_1_toggle ()
	if _tl("AB_OVH_FUELPR1", 0) then
		FuelPump_R_1_on ()
	else
		FuelPump_R_1_off ()
	end
end

function FuelPump_R_2_on ()
    ipc.writeLvar("L:AB_OVH_FUELPR2", 1)
    SmallOverheadPushButtons ()
    DspShow ("PmpR", "2 on")
end

function FuelPump_R_2_off ()
    ipc.writeLvar("L:AB_OVH_FUELPR2", 0)
    SmallOverheadPushButtons ()
    DspShow ("PmpR", "2off")
end

function FuelPump_R_2_toggle ()
	if _tl("AB_OVH_FUELPR2", 0) then
		FuelPump_R_2_on ()
	else
		FuelPump_R_2_off ()
	end
end

function FuelPump_R_BOTH_on ()
    FuelPump_R_1_on ()
    _sleep(100,250)
    FuelPump_R_2_on ()
end

function FuelPump_R_BOTH_off ()
    FuelPump_R_1_off ()
    _sleep(100,250)
    FuelPump_R_2_off ()
end

function FuelPump_R_BOTH_toggle ()
	if _t("FuelPump_RBOTH") then
		FuelPump_R_BOTH_on ()
	else
		FuelPump_R_BOTH_off ()
	end
end

function FuelPumps_ALL_on ()
    FuelPump_L_BOTH_on ()
    _sleep(100,250)
    FuelPump_C_BOTH_on ()
    _sleep(100,250)
    FuelPump_R_BOTH_on ()
end

function FuelPumps_ALL_off ()
    FuelPump_L_BOTH_off ()
    _sleep(100,250)
    FuelPump_C_BOTH_off ()
    _sleep(100,250)
    FuelPump_R_BOTH_off ()
end

function FuelXFeed_on ()
    ipc.writeLvar("L:AB_OVH_FUELXF", 1)
    SmallOverheadPushButtons ()
    DspShow ("XFed", "on")
end

function FuelXFeed_off ()
    ipc.writeLvar("L:AB_OVH_FUELXF", 0)
    SmallOverheadPushButtons ()
    DspShow ("XFed", "off")
end

function FuelXFeed_toggle ()
	if _tl("AB_OVH_FUELXF", 0) then
		FuelXFeed_on ()
	else
		FuelXFeed_off ()
	end
end

function Fuel_Mode_auto ()
    ipc.writeLvar("L:AB_OVH_FUELMODE", 1)
    SmallOverheadPushButtons ()
    DspShow ("FMod", "auto")
end

function Fuel_Mode_manual ()
    ipc.writeLvar("L:AB_OVH_FUELMODE", 0)
    SmallOverheadPushButtons ()
    DspShow ("FMod", "man")
end

function Fuel_Mode_toggle ()
	if _tl("AB_OVH_FUELMODE", 0) then
		Fuel_Mode_auto ()
	else
		Fuel_Mode_manual()
	end
end

-- ## OVHD Hydr ###############

function Hyd_Pump_L_on ()
    ipc.writeLvar("L:AB_OVH_HYDL", 1)
    SmallOverheadPushButtons ()
    DspShow ("HydP", "1 on")
end

function Hyd_Pump_L_off ()

    ipc.writeLvar("L:AB_OVH_HYDL", 0)
    SmallOverheadPushButtons ()
    DspShow ("HydP", "1off")
end

function Hyd_Pump_L_toggle ()
	if _tl("AB_OVH_HYDL", 0) then
		Hyd_Pump_L_on ()
	else
		Hyd_Pump_L_off()
	end
end

function Hyd_Pump_R_on ()
    ipc.writeLvar("L:AB_OVH_HYDR", 1)
    SmallOverheadPushButtons ()
    DspShow ("HydP", "2 on")
end

function Hyd_Pump_R_off ()
    ipc.writeLvar("L:AB_OVH_HYDR", 0)
    SmallOverheadPushButtons ()
    DspShow ("HydP", "2off")
end

function Hyd_Pump_R_toggle ()
	if _tl("AB_OVH_HYDR", 0) then
		Hyd_Pump_R_on ()
	else
		Hyd_Pump_R_off()
	end
end

function Hyd_PTU_auto ()
    ipc.writeLvar("L:AB_OVH_HYDPTU", 1)
    SmallOverheadPushButtons ()
    DspShow ("PTU", "auto")
end

function Hyd_PTU_off ()
    ipc.writeLvar("L:AB_OVH_HYDPTU", 0)
    SmallOverheadPushButtons ()
    DspShow ("PTU", "off")
end

function Hyd_PTU_toggle ()
	if _tl("AB_OVH_HYDPTU", 0) then
		Hyd_PTU_auto ()
	else
		Hyd_PTU_off()
	end
end

function Hyd_Elec_Pump1_Cover_open ()
    ipc.writeLvar("L:AB_OVH_HYDELEC1_COVER", 1)
end

function Hyd_Elec_Pump1_Cover_close ()
    ipc.writeLvar("L:AB_OVH_HYDELEC1_COVER", 0)
end

function Hyd_Elec_Pump1_Cover_toggle ()
	if _tl("AB_OVH_HYDELEC1_COVER", 0) then
		Hyd_Elec_Pump1_Cover_open ()
	else
		Hyd_Elec_Pump1_Cover_close ()
	end
end

function Hyd_Elec_Pump1_auto ()
    ipc.writeLvar("L:AB_OVH_HYDELEC1", 1)
    SmallOverheadPushButtons ()
    _sleep(300,600)
    Hyd_Elec_Pump1_Cover_close ()
    DspShow ("EPmp", "1 on")
end

function Hyd_Elec_Pump1_off ()
    Hyd_Elec_Pump1_Cover_open ()
    _sleep(300,600)
    ipc.writeLvar("L:AB_OVH_HYDELEC1", 0)
    SmallOverheadPushButtons ()
    DspShow ("EPmp", "1off")
end

function Hyd_Elec_Pump1_toggle ()
	if _tl("AB_OVH_HYDELEC1", 0) then
		Hyd_Elec_Pump1_auto ()
	else
		Hyd_Elec_Pump1_off()
	end
end

function Hyd_Elec_Pump2_on ()
    ipc.writeLvar("L:AB_OVH_HYDELEC2", 1)
    SmallOverheadPushButtons ()
    DspShow ("EPmp", "2 on")
    ipc.sleep(200)
    if ipc.readLvar("L:AB_OVH_HYDELEC2") == 0 then
    DspShow ("EPmp", "fail")
    end
end

function Hyd_Elec_Pump2_off ()
    ipc.writeLvar("L:AB_OVH_HYDELEC2", 0)
    SmallOverheadPushButtons ()
    DspShow ("EPmp", "2off")
end

function Hyd_Elec_Pump2_toggle ()
	if _tl("AB_OVH_HYDELEC2", 0) then
		Hyd_Elec_Pump2_on ()
	else
		Hyd_Elec_Pump2_off()
	end
end


-- ## OVHD ADIRS ###############

function IRS1_off ()
    ipc.writeLvar("AB_OVH_IRS1_KNOB", 0)
    LightSwitch ()
    DspShow ("IRS1", "off")
end

function IRS1_nav ()
    ipc.writeLvar("AB_OVH_IRS1_KNOB", 1)
    LightSwitch ()
    DspShow ("IRS1", "nav")
end

function IRS1_att ()
    ipc.writeLvar("AB_OVH_IRS1_KNOB", 2)
    LightSwitch ()
    DspShow ("IRS1", "att")
end

function IRS1_inc ()
    IRS1var = ipc.readLvar("AB_OVH_IRS1_KNOB")
    if IRS1var == 0 then IRS1_nav ()
    elseif IRS1var == 1 then IRS1_att ()
    end
end

function IRS1_dec ()
    IRS1var = ipc.readLvar("AB_OVH_IRS1_KNOB")
    if IRS1var == 2 then IRS1_nav ()
    elseif IRS1var == 1 then IRS1_off ()
    end
end

function IRS2_off ()
    ipc.writeLvar("AB_OVH_IRS2_KNOB", 0)
    LightSwitch ()
    DspShow ("IRS2", "off")
end

function IRS2_nav ()
    ipc.writeLvar("AB_OVH_IRS2_KNOB", 1)
    LightSwitch ()
    DspShow ("IRS2", "nav")
end

function IRS2_att ()
    ipc.writeLvar("AB_OVH_IRS2_KNOB", 2)
    LightSwitch ()
    DspShow ("IRS2", "att")
end

function IRS2_inc ()
    IRS2var = ipc.readLvar("AB_OVH_IRS2_KNOB")
    if IRS2var == 0 then IRS2_nav ()
    elseif IRS2var == 1 then IRS2_att ()
    end
end

function IRS2_dec ()
    IRS2var = ipc.readLvar("AB_OVH_IRS2_KNOB")
    if IRS2var == 2 then IRS2_nav ()
    elseif IRS2var == 1 then IRS2_off ()
    end
end

function IRS3_off ()
    ipc.writeLvar("AB_OVH_IRS3_KNOB", 0)
    LightSwitch ()
    DspShow ("IRS3", "off")
end

function IRS3_nav ()
    ipc.writeLvar("AB_OVH_IRS3_KNOB", 1)
    LightSwitch ()
    DspShow ("IRS3", "nav")
end

function IRS3_att ()
    ipc.writeLvar("AB_OVH_IRS3_KNOB", 2)
    LightSwitch ()
    DspShow ("IRS3", "att")
end

function IRS3_inc ()
    IRS3var = ipc.readLvar("AB_OVH_IRS3_KNOB")
    if IRS3var == 0 then IRS3_nav ()
    elseif IRS3var == 1 then IRS3_att ()
    end
end

function IRS3_dec ()
    IRS3var = ipc.readLvar("AB_OVH_IRS3_KNOB")
    if IRS3var == 2 then IRS3_nav ()
    elseif IRS3var == 1 then IRS3_off ()
    end
end

function IRS_ALL_off ()
    IRS1_off ()
    _sleep(100,200)
    IRS2_off ()
    _sleep(100,200)
    IRS3_off ()
end

function IRS_ALL_nav ()
    IRS1_nav ()
    _sleep(100,200)
    IRS2_nav ()
    _sleep(100,200)
    IRS3_nav ()
end

function IRS_ALL_att ()
    IRS1_att ()
    _sleep(100,200)
    IRS2_att ()
    _sleep(100,200)
    IRS3_att ()
end

function IRS_ALL_inc ()
    IRS1_inc ()
    _sleep(100,200)
    IRS2_inc ()
    _sleep(100,200)
    IRS3_inc ()
end

function IRS_ALL_dec ()
    IRS1_dec ()
    _sleep(100,200)
    IRS2_dec ()
    _sleep(100,200)
    IRS3_dec ()
end

function IRS1_Button_on ()
    ipc.writeLvar("L:AB_OVH_IRS1_BUT", 1)
    SmallOverheadPushButtons ()
    DspShow ("IR1", "on")
end

function IRS1_Button_off ()
    ipc.writeLvar("L:AB_OVH_IRS1_BUT", 0)
    SmallOverheadPushButtons ()
    DspShow ("IR1", "off")
end

function IRS1_Button_toggle ()
	if _tl("AB_OVH_IRS1_BUT", 0) then
		IRS1_Button_on ()
	else
		IRS1_Button_off()
	end
end


function IRS2_Button_on ()
    ipc.writeLvar("L:AB_OVH_IRS2_BUT", 1)
    SmallOverheadPushButtons ()
    DspShow ("IR2", "on")
end

function IRS2_Button_off ()
    ipc.writeLvar("L:AB_OVH_IRS2_BUT", 0)
    SmallOverheadPushButtons ()
    DspShow ("IR2", "off")
end

function IRS2_Button_toggle ()
	if _tl("AB_OVH_IRS2_BUT", 0) then
		IRS2_Button_on ()
	else
		IRS2_Button_off()
	end
end

function IRS3_Button_on ()
    ipc.writeLvar("L:AB_OVH_IRS3_BUT", 1)
    SmallOverheadPushButtons ()
    DspShow ("IR3", "on")
end

function IRS3_Button_off ()
    ipc.writeLvar("L:AB_OVH_IRS3_BUT", 0)
    SmallOverheadPushButtons ()
    DspShow ("IR3", "off")
end

function IRS3_Button_toggle ()
	if _tl("AB_OVH_IRS3_BUT", 0) then
		IRS3_Button_on ()
	else
		IRS3_Button_off()
	end
end

function IRS_ALL_Button_on ()
    IRS1_Button_on ()
    _sleep(100,200)
    IRS2_Button_on ()
    _sleep(100,200)
    IRS3_Button_on ()
end

function IRS_ALL_Button_off ()
    IRS1_Button_off ()
    _sleep(100,200)
    IRS2_Button_off ()
    _sleep(100,200)
    IRS3_Button_off ()
end

function IRS_ALL_Button_toggle ()
    IRS1_Button_toggle ()
    _sleep(100,200)
    IRS2_Button_toggle ()
    _sleep(100,200)
    IRS3_Button_toggle ()
end

function ADR1_Button_on ()
    ipc.writeLvar("L:AB_OVH_ADR1", 1)
    SmallOverheadPushButtons ()
    DspShow ("ADR1", "on")
end

function ADR1_Button_off ()
    ipc.writeLvar("L:AB_OVH_ADR1", 0)
    SmallOverheadPushButtons ()
    DspShow ("ADR1", "off")
end

function ADR1_Button_toggle ()
	if _tl("AB_OVH_ADR1", 0) then
		ADR1_Button_on ()
	else
		ADR1_Button_off()
	end
end

function ADR2_Button_on ()
    ipc.writeLvar("L:AB_OVH_ADR2", 1)
    SmallOverheadPushButtons ()
    DspShow ("ADR2", "on")
end

function ADR2_Button_off ()
    ipc.writeLvar("L:AB_OVH_ADR2", 0)
    SmallOverheadPushButtons ()
    DspShow ("ADR2", "off")
end

function ADR2_Button_toggle ()
	if _tl("AB_OVH_ADR2", 0) then
		ADR2_Button_on ()
	else
		ADR2_Button_off()
	end
end

function ADR3_Button_on ()
    ipc.writeLvar("L:AB_OVH_ADR3", 1)
    SmallOverheadPushButtons ()
    DspShow ("ADR3", "on")
end

function ADR3_Button_off ()
    ipc.writeLvar("L:AB_OVH_ADR3", 0)
    SmallOverheadPushButtons ()
    DspShow ("ADR3", "off")
end

function ADR3_Button_toggle ()
	if _tl("AB_OVH_ADR3", 0) then
		ADR3_Button_on ()
	else
		ADR3_Button_off()
	end
end

function ADR_ALL_Button_on ()
    ADR1_Button_on ()
    _sleep(100,200)
    ADR2_Button_on ()
    _sleep(100,200)
    ADR3_Button_on ()
end

function ADR_ALL_Button_off ()
    ADR1_Button_off ()
    _sleep(100,200)
    ADR2_Button_off ()
    _sleep(100,200)
    ADR3_Button_off ()
end

function ADR_ALL_Button_toggle ()
    ADR1_Button_toggle ()
    _sleep(100,200)
    ADR2_Button_toggle ()
    _sleep(100,200)
    ADR3_Button_toggle ()
end


-- ## OVHD FLT CTL ###############

function ELAC1_on ()
    ipc.writeLvar("L:FBW_ELAC_1", 1)
    SmallOverheadPushButtons ()
    DspShow ("ELAC", "1 on")
end

function ELAC1_off ()
    ipc.writeLvar("L:FBW_ELAC_1", 0)
    SmallOverheadPushButtons ()
    DspShow ("ELAC", "1off")
end

function ELAC1_toggle ()
	if _tl("FBW_ELAC_1", 0) then
		ELAC1_on ()
	else
		ELAC1_off()
	end
end

function ELAC2_on ()
    ipc.writeLvar("L:FBW_ELAC_2", 1)
    SmallOverheadPushButtons ()
    DspShow ("ELAC", "2 on")
end

function ELAC2_off ()
    ipc.writeLvar("L:FBW_ELAC_2", 0)
    SmallOverheadPushButtons ()
    DspShow ("ELAC", "2off")
end

function ELAC2_toggle ()
	if _tl("FBW_ELAC_2", 0) then
		ELAC2_on ()
	else
		ELAC2_off()
	end
end

function SEC1_on ()
    ipc.writeLvar("L:FBW_SEC_1", 1)
    SmallOverheadPushButtons ()
    DspShow ("SEC", "1 on")
end

function SEC1_off ()
    ipc.writeLvar("L:FBW_SEC_1", 0)
    SmallOverheadPushButtons ()
    DspShow ("SEC", "1off")
end

function SEC1_toggle ()
	if _tl("FBW_SEC_1", 0) then
		SEC1_on ()
	else
		SEC1_off()
	end
end

function SEC2_on ()
    ipc.writeLvar("L:FBW_SEC_2", 1)
    SmallOverheadPushButtons ()
    DspShow ("SEC", "2 on")
end

function SEC2_off ()
    ipc.writeLvar("L:FBW_SEC_2", 0)
    SmallOverheadPushButtons ()
    DspShow ("SEC", "2off")
end

function SEC2_toggle ()
	if _tl("FBW_SEC_2", 0) then
		SEC2_on ()
	else
		SEC2_off()
	end
end

function SEC3_on ()
    ipc.writeLvar("L:FBW_SEC_3", 1)
    SmallOverheadPushButtons ()
    DspShow ("SEC", "3 on")
end

function SEC3_off ()
    ipc.writeLvar("L:FBW_SEC_3", 0)
    SmallOverheadPushButtons ()
    DspShow ("SEC", "3off")
end

function SEC3_toggle ()
	if _tl("FBW_SEC_3", 0) then
		SEC3_on ()
	else
		SEC3_off()
	end
end

function FAC1_on ()
    ipc.writeLvar("L:FBW_FAC_1", 1)
    SmallOverheadPushButtons ()
    DspShow ("FAC", "1 on")
end

function FAC1_off ()
    ipc.writeLvar("L:FBW_FAC_1", 0)
    SmallOverheadPushButtons ()
    DspShow ("FAC", "1off")
end

function FAC1_toggle ()
	if _tl("FBW_FAC_1", 0) then
		FAC1_on ()
	else
		FAC1_off()
	end
end

function FAC2_on ()
    ipc.writeLvar("L:FBW_FAC_2", 1)
    SmallOverheadPushButtons ()
    DspShow ("FAC", "2 on")
end

function FAC2_off ()
    ipc.writeLvar("L:FBW_FAC_2", 0)
    SmallOverheadPushButtons ()
    DspShow ("FAC", "2off")
end

function FAC2_toggle ()
	if _tl("FBW_FAC_2", 0) then
		FAC2_on ()
	else
		FAC2_off()
	end
end


-- ## GWPS ###############

function AB_OVH_GPWS_TERR_on ()
    ipc.writeLvar("L:AB_OVH_GPWS_TERR", 1)
    SmallOverheadPushButtons ()
    DspShow ("Terr", "on")
end

function AB_OVH_GPWS_TERR_off ()
    ipc.writeLvar("L:AB_OVH_GPWS_TERR", 0)
    SmallOverheadPushButtons ()
    DspShow ("Terr", "off")
end

function AB_OVH_GPWS_TERR_toggle ()
	if _tl("AB_OVH_GPWS_TERR", 0) then
		AB_OVH_GPWS_TERR_on ()
	else
		AB_OVH_GPWS_TERR_off()
	end
end

function OVHD_GWPS_SYS_on ()
    ipc.writeLvar("L:AB_OVH_GPWS_SYS", 1)
    SmallOverheadPushButtons ()
    DspShow ("SYS", "on")
end

function OVHD_GWPS_SYS_off ()
    ipc.writeLvar("L:AB_OVH_GPWS_SYS", 0)
    SmallOverheadPushButtons ()
    DspShow ("SYS", "off")
end

function OVHD_GWPS_SYS_toggle ()
	if _tl("AB_OVH_GPWS_SYS", 0) then
		OVHD_GWPS_SYS_on ()
	else
		OVHD_GWPS_SYS_off()
	end
end

function OVHD_GWPS_GSMODE_on ()
    ipc.writeLvar("L:AB_OVH_GPWS_GSMODE", 1)
    SmallOverheadPushButtons ()
    DspShow ("GSMD", "on")
end

function OVHD_GWPS_GSMODE_off ()
    ipc.writeLvar("L:AB_OVH_GPWS_GSMODE", 0)
    SmallOverheadPushButtons ()
    DspShow ("GSMD", "off")
end

function OVHD_GWPS_GSMODE_toggle ()
	if _tl("AB_OVH_GPWS_GSMODE", 0) then
		OVHD_GWPS_GSMODE_on ()
	else
		OVHD_GWPS_GSMODE_off()
	end
end

function AB_OVH_GPWS_FLAPMODE_on ()
    ipc.writeLvar("L:AB_OVH_GPWS_FLAPMODE", 1)
    SmallOverheadPushButtons ()
    DspShow ("FLPM", "on")
end

function AB_OVH_GPWS_FLAPMODE_off ()

    ipc.writeLvar("L:AB_OVH_GPWS_FLAPMODE", 0)
    SmallOverheadPushButtons ()
    DspShow ("FLPM", "off")
end

function AB_OVH_GPWS_FLAPMODE_toggle ()
	if _tl("AB_OVH_GPWS_FLAPMODE", 0) then
		AB_OVH_GPWS_FLAPMODE_on ()
	else
		AB_OVH_GPWS_FLAPMODE_off()
	end
end

function AB_OVH_GPWS_LDGFLAP3_on ()
    ipc.writeLvar("L:AB_OVH_GPWS_LDGFLAP3", 1)
    SmallOverheadPushButtons ()
    DspShow ("LDGF", "on")
end

function AB_OVH_GPWS_LDGFLAP3_off ()
    ipc.writeLvar("L:AB_OVH_GPWS_LDGFLAP3", 0)
    SmallOverheadPushButtons ()
    DspShow ("LDGF", "off")
end

function AB_OVH_GPWS_LDGFLAP3_toggle ()
	if _tl("AB_OVH_GPWS_LDGFLAP3", 0) then
		AB_OVH_GPWS_LDGFLAP3_on ()
	else
		AB_OVH_GPWS_LDGFLAP3_off()
	end
end


-- ## OVHD RCDR ###############

function AB_OVH_FLTRCD_button_on ()
    ipc.writeLvar("L:AB_OVH_FLTRCD_button", 1)
    SmallOverheadPushButtons ()
    DspShow ("FREC", "on")
end

function AB_OVH_FLTRCD_button_off ()
    ipc.writeLvar("L:AB_OVH_FLTRCD_button", 0)
    SmallOverheadPushButtons ()
    DspShow ("FREC", "off")
end

function AB_OVH_FLTRCD_button_toggle ()
	if _tl("AB_OVH_FLTRCD_button", 0) then
		AB_OVH_FLTRCD_button_on ()
	else
		AB_OVH_FLTRCD_button_off()
	end
end

function AB_OVH_FLTRCD_erase ()
    ipc.writeLvar("L:AB_OVH_FLTRCD_erase", 1)
    SmallOverheadPushButtons ()
    DspShow ("FREC", "del")
end

function AB_OVH_FLTRCD_test ()
    ipc.writeLvar("L:AB_OVH_FLTRCD_test", 1)
    SmallOverheadPushButtons ()
    DspShow ("FREC", "test")
end


-- ## Other Overhead ###############

function AB_WiperL_slow ()
    ipc.writeLvar("AB_OVH_WIPERL_KNOB", 25)
    ipc.writeLvar("AB_wiperL", 1)
    ASC_KnobRotate ()
    DspShow ("WipL", "slow")
end

function AB_WiperL_fast ()
    ipc.writeLvar("AB_OVH_WIPERL_KNOB", 50)
    ipc.writeLvar("AB_wiperL", 2)
    ASC_KnobRotate ()
    DspShow ("WipL", "fast")
end

function AB_WiperL_off ()
    ipc.writeLvar("AB_OVH_WIPERL_KNOB", 0)
    ipc.writeLvar("AB_wiperL", 0)
    ASC_KnobRotate ()
    DspShow ("WipL", "off")
end

function AB_WiperR_slow ()
    ipc.writeLvar("AB_OVH_WIPERR_KNOB", 25)
    ipc.writeLvar("AB_wiperR", 1)
    ASC_KnobRotate ()
    DspShow ("WipR", "slow")
end

function AB_WiperR_fast ()
    ipc.writeLvar("AB_OVH_WIPERR_KNOB", 50)
    ipc.writeLvar("AB_wiperR", 2)
    ASC_KnobRotate ()
    DspShow ("WipR", "fast")
end

function AB_WiperR_off ()
    ipc.writeLvar("AB_OVH_WIPERR_KNOB", 0)
    ipc.writeLvar("AB_wiperR", 0)
    ASC_KnobRotate ()
    DspShow ("WipR", "off")
end

function AB_WiperL_inc ()
    WipL = ipc.readLvar("AB_OVH_WIPERL_KNOB")
    if WipL == 0 then
    AB_WiperL_slow ()
    elseif WipL == 25 then
    AB_WiperL_fast ()
    end
end

function AB_WiperL_dec ()
    WipL = ipc.readLvar("AB_OVH_WIPERL_KNOB")
    if WipL == 50 then
    AB_WiperL_slow ()
    elseif WipL == 25 then
    AB_WiperL_off ()
    end
end

function AB_WiperR_inc ()
    WipR = ipc.readLvar("AB_OVH_WIPERR_KNOB")
    if WipR == 0 then
    AB_WiperR_slow ()
    elseif WipR == 25 then
    AB_WiperR_fast ()
    end
end

function AB_WiperR_dec ()
    WipR = ipc.readLvar("AB_OVH_WIPERR_KNOB")
    if WipR == 50 then
    AB_WiperR_slow ()
    elseif WipR == 25 then
    AB_WiperR_off ()
    end
end

function AB_Wiper_both_slow ()
    AB_WiperL_slow ()
    _sleep(300,600)
    AB_WiperR_slow ()
end

function AB_Wiper_both_fast ()
    AB_WiperL_fast ()
    _sleep(300,600)
    AB_WiperR_fast ()
end

function AB_Wiper_both_off ()
    AB_WiperL_off ()
    _sleep(300,500)
    AB_WiperR_off ()
end

function AB_Wiper_both_inc ()
    AB_WiperL_inc ()
    _sleep(100,200)
    AB_WiperR_inc ()
end

function AB_Wiper_both_dec ()
    AB_WiperL_dec ()
    _sleep(100,200)
    AB_WiperR_dec ()
end


-- ## MCDU left ###############

function MCDU_KEYB_on ()
    ipc.writeLvar("L:MCDU_KBD", 1)
    ipc.sleep(50)
    ipc.set("MCDU", ipc.elapsedtime())
    AB_MCDU_KeyFlag = true
    DspShow("MCDU","KOn")
end

function MCDU_KEYB_off()
    ipc.writeLvar("L:MCDU_KBD", 0)
    ipc.sleep(50)
    AB_MCDU_KeyFlag = false
    DspShow("MCDU","KOff")
end

function MCDU_KEYB_toggle()
    if ipc.readLvar("L:MCDU_KBD") == 1 then
        MCDU_KEYB_off()
    else
        MCDU_KEYB_on()
    end
end

function MCDU_LSK1L ()
    ipc.writeLvar("L:MCDU_LSK1L", 1)
    ASC_MCDU_CLICK ()
end

function MCDU_LSK2L ()
    ipc.writeLvar("L:MCDU_LSK2L", 1)
    ASC_MCDU_CLICK ()
end

function MCDU_LSK3L ()
    ipc.writeLvar("L:MCDU_LSK3L", 1)
    ASC_MCDU_CLICK ()
end

function MCDU_LSK4L ()
    ipc.writeLvar("L:MCDU_LSK4L", 1)
    ASC_MCDU_CLICK ()
end

function MCDU_LSK5L ()
    ipc.writeLvar("L:MCDU_LSK5L", 1)
    ASC_MCDU_CLICK ()
end

function MCDU_LSK6L ()
    ipc.writeLvar("L:MCDU_LSK6L", 1)
    ASC_MCDU_CLICK ()
end

-------

function MCDU_LSK1R ()
    ipc.writeLvar("L:MCDU_LSK1R", 1)
    ASC_MCDU_CLICK ()
end

function MCDU_LSK2R ()
    ipc.writeLvar("L:MCDU_LSK2R", 1)
    ASC_MCDU_CLICK ()
end

function MCDU_LSK3R ()
    ipc.writeLvar("L:MCDU_LSK3R", 1)
    ASC_MCDU_CLICK ()
end

function MCDU_LSK4R ()
    ipc.writeLvar("L:MCDU_LSK4R", 1)
    ASC_MCDU_CLICK ()
end

function MCDU_LSK5R ()
    ipc.writeLvar("L:MCDU_LSK5R", 1)
    ASC_MCDU_CLICK ()
end

function MCDU_LSK6R ()
    ipc.writeLvar("L:MCDU_LSK6R", 1)
    ASC_MCDU_CLICK ()
end

-----

function MCDU1_DIR_key ()
    ipc.writeLvar("L:MCDU1_DIR_key", 1)
    ASC_MCDU_CLICK ()
end

function MCDU1_PROG_key ()
    ipc.writeLvar("L:MCDU1_PROG_key", 1)
    ASC_MCDU_CLICK ()
end

function MCDU1_PERF_key ()
    ipc.writeLvar("L:MCDU1_PERF_key", 1)
    ASC_MCDU_CLICK ()
end

function MCDU1_INIT_key ()
    ipc.writeLvar("L:MCDU1_INIT_key", 1)
    ASC_MCDU_CLICK ()
end

function MCDU1_DATA_key ()
    ipc.writeLvar("L:MCDU1_DATA_key", 1)
    ASC_MCDU_CLICK ()
end

function MCDU1_FPLN_key ()
    ipc.writeLvar("L:MCDU1_FPLN_key", 1)
    ASC_MCDU_CLICK ()
end

function MCDU1_RAD_key ()
    ipc.writeLvar("L:MCDU1_RAD_key", 1)
    ASC_MCDU_CLICK ()
end

function MCDU1_FUEL_key ()
    ipc.writeLvar("L:MCDU1_FUEL_key", 1)
    ASC_MCDU_CLICK ()
end

function MCDU1_SPLN_key ()
    ipc.writeLvar("L:MCDU1_SPLN_key", 1)
    ASC_MCDU_CLICK ()
end

function MCDU1_ATC_key ()
    ipc.writeLvar("L:MCDU1_ATC_key", 1)
    ASC_MCDU_CLICK ()
end

function MCDU1_MENU_key ()
    ipc.writeLvar("L:MCDU1_MENU_key", 1)
    ASC_MCDU_CLICK ()
end

function MCDU1_ARPRT_key ()
    ipc.writeLvar("L:MCDU1_ARPRT_key", 1)
    ASC_MCDU_CLICK ()
end

----------

function MCDU_arrowdn ()
    ipc.writeLvar("L:MCDU_arrowdn", 1)
    ASC_MCDU_CLICK ()
end

function MCDU_arrowleft ()
    ipc.writeLvar("L:MCDU_arrowleft", 1)
    ASC_MCDU_CLICK ()
end

function MCDU_arrowright ()
    ipc.writeLvar("L:MCDU_arrowright", 1)
    ASC_MCDU_CLICK ()
end

function MCDU_arrowup ()
    ipc.writeLvar("L:MCDU_arrowup", 1)
    ASC_MCDU_CLICK ()
end

---------

function MCDU_0 ()
    ipc.writeLvar("L:MCDU_0", 1)
    ASC_MCDU_CLICK ()
end

function MCDU_1 ()
    ipc.writeLvar("L:MCDU_1", 1)
    ASC_MCDU_CLICK ()
end

function MCDU_2 ()
    ipc.writeLvar("L:MCDU_2", 1)
    ASC_MCDU_CLICK ()
end

function MCDU_3 ()
    ipc.writeLvar("L:MCDU_3", 1)
    ASC_MCDU_CLICK ()
end

function MCDU_4 ()
    ipc.writeLvar("L:MCDU_4", 1)
    ASC_MCDU_CLICK ()
end

function MCDU_5 ()
    ipc.writeLvar("L:MCDU_5", 1)
    ASC_MCDU_CLICK ()
end

function MCDU_6 ()
    ipc.writeLvar("L:MCDU_6", 1)
    ASC_MCDU_CLICK ()
end

function MCDU_7 ()
    ipc.writeLvar("L:MCDU_7", 1)
    ASC_MCDU_CLICK ()
end

function MCDU_8 ()
    ipc.writeLvar("L:MCDU_8", 1)
    ASC_MCDU_CLICK ()
end

function MCDU_9 ()
    ipc.writeLvar("L:MCDU_9", 1)
    ASC_MCDU_CLICK ()
end

-----------------
-----------------

function MCDU_A ()
    ipc.writeLvar("L:MCDU_A", 1)
    ASC_MCDU_CLICK ()
end

function MCDU_B ()
    ipc.writeLvar("L:MCDU_B", 1)
    ASC_MCDU_CLICK ()
end

function MCDU_C ()
    ipc.writeLvar("L:MCDU_C", 1)
    ASC_MCDU_CLICK ()
end

function MCDU_D ()
    ipc.writeLvar("L:MCDU_D", 1)
    ASC_MCDU_CLICK ()
end

function MCDU_E ()
    ipc.writeLvar("L:MCDU_E", 1)
    ASC_MCDU_CLICK ()
end

function MCDU_F ()
    ipc.writeLvar("L:MCDU_F", 1)
    ASC_MCDU_CLICK ()
end

function MCDU_G ()
    ipc.writeLvar("L:MCDU_G", 1)
    ASC_MCDU_CLICK ()
end

function MCDU_H ()
    ipc.writeLvar("L:MCDU_H", 1)
    ASC_MCDU_CLICK ()
end

function MCDU_I ()
    ipc.writeLvar("L:MCDU_I", 1)
    ASC_MCDU_CLICK ()
end

function MCDU_J ()
    ipc.writeLvar("L:MCDU_J", 1)
    ASC_MCDU_CLICK ()
end

function MCDU_K ()
    ipc.writeLvar("L:MCDU_K", 1)
    ASC_MCDU_CLICK ()
end

function MCDU_L ()
    ipc.writeLvar("L:MCDU_L", 1)
    ASC_MCDU_CLICK ()
end

function MCDU_M ()
    ipc.writeLvar("L:MCDU_M", 1)
    ASC_MCDU_CLICK ()
end

function MCDU_N ()
    ipc.writeLvar("L:MCDU_N", 1)
    ASC_MCDU_CLICK ()
end

function MCDU_O ()
    ipc.writeLvar("L:MCDU_O", 1)
    ASC_MCDU_CLICK ()
end

function MCDU_P ()
    ipc.writeLvar("L:MCDU_P", 1)
    ASC_MCDU_CLICK ()
end

function MCDU_Q ()
    ipc.writeLvar("L:MCDU_Q", 1)
    ASC_MCDU_CLICK ()
end

function MCDU_R ()
    ipc.writeLvar("L:MCDU_R", 1)
    ASC_MCDU_CLICK ()
end

function MCDU_S ()
    ipc.writeLvar("L:MCDU_S", 1)
    ASC_MCDU_CLICK ()
end

function MCDU_T ()
    ipc.writeLvar("L:MCDU_T", 1)
    ASC_MCDU_CLICK ()
end

function MCDU_U ()
    ipc.writeLvar("L:MCDU_U", 1)
    ASC_MCDU_CLICK ()
end

function MCDU_V ()
    ipc.writeLvar("L:MCDU_V", 1)
    ASC_MCDU_CLICK ()
end

function MCDU_W ()
    ipc.writeLvar("L:MCDU_W", 1)
    ASC_MCDU_CLICK ()
end

function MCDU_X ()
    ipc.writeLvar("L:MCDU_X", 1)
    ASC_MCDU_CLICK ()
end

function MCDU_Y ()
    ipc.writeLvar("L:MCDU_Y", 1)
    ASC_MCDU_CLICK ()
end

function MCDU_Z ()
    ipc.writeLvar("L:MCDU_Z", 1)
    ASC_MCDU_CLICK ()
end

----

function MCDU_SP ()
    ipc.writeLvar("L:MCDU_SP", 1)
    ASC_MCDU_CLICK ()
end

function MCDU_OVFLY ()
    ipc.writeLvar("L:MCDU_OVFLY", 1)
    ASC_MCDU_CLICK ()
end

function MCDU_CLR ()
    ipc.writeLvar("L:MCDU_CLR", 1)
    ASC_MCDU_CLICK ()
end


function MCDU_SLASH ()
    ipc.writeLvar("L:MCDU_SL", 1)
    ASC_MCDU_CLICK ()
end

function MCDU_PLUSMINUS ()
    ipc.writeLvar("L:MCDU_SGN", 1)
    ASC_MCDU_CLICK ()
end

function MCDU_POINT ()
    ipc.writeLvar("L:MCDU_ST", 1)
    ASC_MCDU_CLICK ()
end

function MCDU_BRT ()
    ipc.writeLvar("L:MCDU_BRT", 1)
    ASC_MCDU_CLICK ()
end

function MCDU_DIM ()
    ipc.writeLvar("L:MCDU_DIM", 1)
    ASC_MCDU_CLICK ()
end

-- ## MCDU right ###############

function MCDU2_LSK1L ()
    ipc.writeLvar("L:MCDU2_LSK1L", 1)
    ASC_MCDU_CLICK ()
end

function MCDU2_LSK2L ()
    ipc.writeLvar("L:MCDU2_LSK2L", 1)
    ASC_MCDU_CLICK ()
end

function MCDU2_LSK3L ()
    ipc.writeLvar("L:MCDU2_LSK3L", 1)
    ASC_MCDU_CLICK ()
end

function MCDU2_LSK4L ()
    ipc.writeLvar("L:MCDU2_LSK4L", 1)
    ASC_MCDU_CLICK ()
end

function MCDU2_LSK5L ()
    ipc.writeLvar("L:MCDU2_LSK5L", 1)
    ASC_MCDU_CLICK ()
end

function MCDU2_LSK6L ()
    ipc.writeLvar("L:MCDU2_LSK6L", 1)
    ASC_MCDU_CLICK ()
end

-------

function MCDU2_LSK1R ()
    ipc.writeLvar("L:MCDU2_LSK1R", 1)
    ASC_MCDU_CLICK ()
end

function MCDU2_LSK2R ()
    ipc.writeLvar("L:MCDU2_LSK2R", 1)
    ASC_MCDU_CLICK ()
end

function MCDU2_LSK3R ()
    ipc.writeLvar("L:MCDU2_LSK3R", 1)
    ASC_MCDU_CLICK ()
end

function MCDU2_LSK4R ()
    ipc.writeLvar("L:MCDU2_LSK4R", 1)
    ASC_MCDU_CLICK ()
end

function MCDU2_LSK5R ()
    ipc.writeLvar("L:MCDU2_LSK5R", 1)
    ASC_MCDU_CLICK ()
end

function MCDU2_LSK6R ()
    ipc.writeLvar("L:MCDU2_LSK6R", 1)
    ASC_MCDU_CLICK ()
end

-----

function MCDU2_arrowleft ()
    ipc.writeLvar("L:MCDU2_arrowleft", 1)
    ASC_MCDU_CLICK ()
end

function MCDU2_arrowright ()
    ipc.writeLvar("L:MCDU2_arrowright", 1)
    ASC_MCDU_CLICK ()
end

function MCDU2_BRT ()
    ipc.writeLvar("L:MCDU2_BRT", 1)
    ASC_MCDU_CLICK ()
end

function MCDU2_DIM ()
    ipc.writeLvar("L:MCDU2_DIM", 1)
    ASC_MCDU_CLICK ()
end

-- ## ECAM ############

function ECAM_ENG ()
    EcamVar = ipc.readLvar("ECAM_Mode")
    if EcamVar ~= 1 then
        ipc.writeLvar("ECAM_Mode", 1)
        ipc.writeLvar("LowECAM_Page", 1)
    else
        ipc.writeLvar("ECAM_Mode", 0)
    end
    SmallOverheadPushButtons ()
	DspShow("ECAM", "ENG ")
end

function ECAM_BLEED ()
    EcamVar = ipc.readLvar("ECAM_Mode")
    if EcamVar ~= 2 then
        ipc.writeLvar("ECAM_Mode", 2)
        ipc.writeLvar("LowECAM_Page", 2)
    else
        ipc.writeLvar("ECAM_Mode", 0)
    end
    SmallOverheadPushButtons ()
	DspShow("ECAM", "BLED")
end

function ECAM_PRESS ()
    EcamVar = ipc.readLvar("ECAM_Mode")
    if EcamVar ~= 3 then
        ipc.writeLvar("ECAM_Mode", 3)
        ipc.writeLvar("LowECAM_Page", 3)
    else
        ipc.writeLvar("ECAM_Mode", 0)
    end
    SmallOverheadPushButtons ()
	DspShow("ECAM", "PRES")
end

function ECAM_ELEC ()
    EcamVar = ipc.readLvar("ECAM_Mode")
    if EcamVar ~= 4 then
        ipc.writeLvar("ECAM_Mode", 4)
        ipc.writeLvar("LowECAM_Page", 4)
    else
        ipc.writeLvar("ECAM_Mode", 0)
    end
    SmallOverheadPushButtons ()
	DspShow("ECAM", "ELEC")
end

function ECAM_HYD ()
    EcamVar = ipc.readLvar("ECAM_Mode")
    if EcamVar ~= 5 then
        ipc.writeLvar("ECAM_Mode", 5)
        ipc.writeLvar("LowECAM_Page", 5)
    else
        ipc.writeLvar("ECAM_Mode", 0)
    end
    SmallOverheadPushButtons ()
	DspShow("ECAM", "HYD ")
end

function ECAM_FUEL ()
    EcamVar = ipc.readLvar("ECAM_Mode")
    if EcamVar ~= 6 then
        ipc.writeLvar("ECAM_Mode", 6)
        ipc.writeLvar("LowECAM_Page", 6)
    else
        ipc.writeLvar("ECAM_Mode", 0)
    end
    SmallOverheadPushButtons ()
	DspShow("ECAM", "FUEL")
end

function ECAM_APU ()
    EcamVar = ipc.readLvar("ECAM_Mode")
    if EcamVar ~= 7 then
        ipc.writeLvar("ECAM_Mode", 7)
        ipc.writeLvar("LowECAM_Page", 7)
    else
        ipc.writeLvar("ECAM_Mode", 0)
    end
    SmallOverheadPushButtons ()
	DspShow("ECAM", "APU ")
end

function ECAM_COND ()
    EcamVar = ipc.readLvar("ECAM_Mode")
    if EcamVar ~= 8 then
        ipc.writeLvar("ECAM_Mode", 8)
        ipc.writeLvar("LowECAM_Page", 8)
    else
        ipc.writeLvar("ECAM_Mode", 0)
    end
    SmallOverheadPushButtons ()
	DspShow("ECAM", "COND")
end

function ECAM_DOOR ()
    EcamVar = ipc.readLvar("ECAM_Mode")
    if EcamVar ~= 9 then
        ipc.writeLvar("ECAM_Mode", 9)
        ipc.writeLvar("LowECAM_Page", 9)
    else
        ipc.writeLvar("ECAM_Mode", 0)
    end
    SmallOverheadPushButtons ()
	DspShow("ECAM", "DOOR")
end

function ECAM_WHEEL ()
    EcamVar = ipc.readLvar("ECAM_Mode")
    if EcamVar ~= 10 then
        ipc.writeLvar("ECAM_Mode", 10)
        ipc.writeLvar("LowECAM_Page", 10)
    else
        ipc.writeLvar("ECAM_Mode", 0)
    end
    SmallOverheadPushButtons ()
	DspShow("ECAM", "WHEL")
end

function ECAM_FCTL ()
    EcamVar = ipc.readLvar("ECAM_Mode")
    if EcamVar ~= 11 then
        ipc.writeLvar("ECAM_Mode", 11)
        ipc.writeLvar("LowECAM_Page", 11)
    else
        ipc.writeLvar("ECAM_Mode", 0)
    end
    SmallOverheadPushButtons ()
	DspShow("ECAM", "FCTL")
end

function ECAM_SYS ()
    EcamVar = ipc.readLvar("ECAM_Mode")
    if EcamVar ~= 13 then
        ipc.writeLvar("ECAM_Mode", 13)
        ipc.writeLvar("LowECAM_Page", 13)
    else
        ipc.writeLvar("ECAM_Mode", 0)
    end
    SmallOverheadPushButtons ()
	DspShow("ECAM", "STS ")
end

function ECAM_NONE ()
    EcamVar = ipc.readLvar("ECAM_Mode")
    if EcamVar ~= 0 then
        ipc.writeLvar("ECAM_Mode", 0)
    end
    SmallOverheadPushButtons ()
	DspShow("ECAM", "None")
end

function ECAM_MODE_next ()
	EcamVar = ipc.readLvar("L:ECAM_Mode")
    if (EcamVar > 11 or EcamVar == 0) then ECAM_ENG ()
    elseif EcamVar == 1 then ECAM_BLEED ()
    elseif EcamVar == 2 then ECAM_PRESS ()
    elseif EcamVar == 3 then ECAM_ELEC ()
    elseif EcamVar == 4 then ECAM_HYD ()
    elseif EcamVar == 5 then ECAM_FUEL ()
    elseif EcamVar == 6 then ECAM_APU ()
    elseif EcamVar == 7 then ECAM_COND ()
    elseif EcamVar == 8 then ECAM_DOOR ()
    elseif EcamVar == 9 then ECAM_WHEEL ()
    elseif EcamVar == 10 then ECAM_FCTL ()
    elseif EcamVar == 11 then ECAM_NONE ()
    end
    ECAM_modes_show ()
end

function ECAM_MODE_prev ()
	EcamVar = ipc.readLvar("L:ECAM_Mode")
    if EcamVar == 2 then ECAM_ENG ()
    elseif EcamVar == 3 then ECAM_BLEED ()
    elseif EcamVar == 4 then ECAM_PRESS ()
    elseif EcamVar == 5 then ECAM_ELEC ()
    elseif EcamVar == 6 then ECAM_HYD ()
    elseif EcamVar == 7 then ECAM_FUEL ()
    elseif EcamVar == 8 then ECAM_APU ()
    elseif EcamVar == 9 then ECAM_COND ()
    elseif EcamVar == 10 then ECAM_DOOR ()
    elseif EcamVar == 11 then ECAM_WHEEL ()
    elseif EcamVar == 0 then ECAM_FCTL()
    elseif EcamVar == 1 then ECAM_NONE ()
    end
    ECAM_modes_show ()
end

function ECAM_ALL ()
    LVarSet = "L:ECAM_Mode"
    ipc.writeLvar(LVarSet, 12)
    SmallOverheadPushButtons ()
    DspShow ("ECAM", "ALL ")
end

function ECAM_CLR ()
    LVarSet = "L:AB_ECAM_CLR"
    ipc.writeLvar(LVarSet, 1)
    SmallOverheadPushButtons ()
    DspShow ("ECAM", "CLR ")
end

function ECAM_RCL ()
    LVarSet = "L:AB_ECAM_RCL"
    ipc.writeLvar(LVarSet, 1)
    SmallOverheadPushButtons ()
    DspShow ("ECAM", "RCL ")
end

function ECAM_TO_CONFIG ()
    ipc.writeLvar("L:AB_ECAM_TOCFG", 1)
	ipc.writeLvar("L:AB_ECAM_TOconf", 1)
	ipc.writeLvar("L:AB_ECAM_TOconf_Hasbeentested", 1)
	ipc.writeLvar("L:AB_ECAM_RCL", 1)
	DspShow ("ECAM", "T/O ")
    SmallOverheadPushButtons ()
 end


-- ## Engine Management ###################################

function Engine1_MASTER_on ()
    LVarSet = "L:AB_PDS_Eng1Master"
    ipc.writeLvar(LVarSet, 1)
    LightSwitch ()
    DspShow ("ENG1", "on")
end

function Engine1_MASTER_off ()
    LVarSet = "L:AB_PDS_Eng1Master"
    ipc.writeLvar(LVarSet, 0)
    LightSwitch ()
    DspShow ("ENG1", "off")
end

function Engine1_MASTER_toggle ()
	if _tl("AB_PDS_Eng1Master", 0) then
		Engine1_MASTER_on ()
	else
		Engine1_MASTER_off ()
	end
end

function Engine2_MASTER_on ()
    LVarSet = "L:AB_PDS_Eng2Master"
    ipc.writeLvar(LVarSet, 1)
    LightSwitch ()
    DspShow ("ENG2", "on")
end

function Engine2_MASTER_off ()
    LVarSet = "L:AB_PDS_Eng2Master"
    ipc.writeLvar(LVarSet, 0)
    LightSwitch ()
    DspShow ("ENG2", "off")
end

function Engine2_MASTER_toggle ()
	if _tl("AB_PDS_Eng2Master", 0) then
		Engine2_MASTER_on ()
	else
		Engine2_MASTER_off ()
	end
end

function Ignition_inc ()
    LVarSet = "L:AB_PDS_ignition"
    var = ipc.readLvar(LVarSet)
    if (var < 2) then
        var = var + 1
        ipc.writeLvar(LVarSet, var)
    end
end

function Ignition_dec ()
    LVarSet = "L:AB_PDS_ignition"
    var = ipc.readLvar(LVarSet)
    if (var > 0) then
        var = var - 1
        ipc.writeLvar(LVarSet, var)
    end
end

function Ignition_start ()
    LVarSet = "L:AB_PDS_ignition"
    ipc.writeLvar(LVarSet, 2)
    LightSwitch ()
    DspShow ("IGN", "start")
end

function Ignition_norm ()
    LVarSet = "L:AB_PDS_ignition"
    ipc.writeLvar(LVarSet, 1)
    LightSwitch ()
    DspShow ("IGN", "norm")
end

function Ignition_crank ()
    LVarSet = "L:AB_PDS_ignition"
    ipc.writeLvar(LVarSet, 0)
    LightSwitch ()
    DspShow ("IGN", "crnk")
end

function Ignition_toggle ()
	if _tl("AB_PDS_ignition", 1) then
       Ignition_start ()
	else
       Ignition_norm ()
	end
end

function ThrustReverse_1 ()
local i, epr
    _loggg('[AB] RevL=' .. ipc.readLvar("L:AS_FADEC_0"))
    i = 100 --0000
    epr = ipc.readLvar("L:TURB ENG1 EPR")
    while (epr > 1.09) and (i > 0) do
        epr = ipc.readLvar("L:TURB ENG1 EPR")
        i = i - 1
    end
    _loggg('[awg] L Eng exit while epr '.. tostring(epr) .. '-' .. tostring(i))
    ipc.writeLvar("L:AS_FADEC_0", 32506)
    for i = 1, 16 do
        ipc.control(65966, 0)
    end
end

function ThrustReverse_2 ()
local i, epr
    _loggg('[AB] RevR=' .. ipc.readLvar("L:AS_FADEC_1"))
    i = 1000000
    epr = ipc.readLvar("L:TURB ENG2 EPR")
    while (epr > 1.02) and (i > 0) do
        epr = ipc.readLvar("L:TURB ENG2 EPR")
        i = i - 1
    end
    _loggg('[awg] R Eng exit while epr '.. tostring(epr) .. '-' .. tostring(i))
    ipc.writeLvar("L:AS_FADEC_1", 32506)
    for i = 1, 16 do
        ipc.control(65966, 0)
    end
end

-- ## Rudder Trim ###############

function AB_Rudder_Trim_show ()
    RuddVal = ipc.readUW(0x0C04)
    if RuddVal >= 49000 then
    RuddVal = (RuddVal - 65487)
    end

    RuddTrimVar = round2((RuddVal*0.006103515625)/5, 1)

    if RuddTrimVar > 0 then
    DirTxt = "R"
    RudTrimTxt = RuddTrimVar
    elseif RuddTrimVar < 0 then
    DirTxt = "L"
    RudTrimTxt = RuddTrimVar*-1
    elseif RuddTrimVar == 0 then
    DirTxt = " "
    end
    DspShow(DirTxt.."Rud", RudTrimTxt)
end

function AB_RudderTrim_R ()
    ipc.writeLvar("Ruddertrimknob", 1)
    ipc.control(66279)
    ipc.sleep(50)
    AB_Rudder_Trim_show ()
end

function AB_RudderTrim_stop ()
    ipc.writeLvar("Ruddertrimknob", 0)
    AB_Rudder_Trim_show ()
end

function AB_RudderTrim_L ()
    ipc.writeLvar("Ruddertrimknob", -1)
    ipc.control(66278)
    ipc.sleep(50)
    AB_Rudder_Trim_show ()
end

function AB_Rudder_reset ()
    ipc.writeLvar("AB_RUDDERTRIM_Neutral_button", 1)
    SmallOverheadPushButtons ()
end

-- ## RADIO CRS/DME ###############

function AB_ILS_test ()
    local ILS_freq = ipc.readLvar("L:MCDU_ILS1")
    local ILS_crs = ipc.readLvar("L:MCDU_ILS1_CRS")
    local ILS_disp = ipc.readLvar("L:AB_MPL_ILS")
    local ILS_name = string.format("%s", ipc.readSTR(0x3000, 5))
    local VOR1_freq = ipc.readLvar("L:MCDU_VOR1")
    local VOR1_crs = ipc.readLvar("L:MCDU_VOR1_CRS")
    local VOR2_freq = ipc.readLvar("L:MCDU_VOR2")
    local VOR2_crs = ipc.readLvar("L:MCDU_VOR2_CRS")
    _log ('[awg] ILS disp  = ' .. ILS_disp)
    _log ('[awg] ILS crs   = ' .. ILS_crs)
    _log ('[awg] ILS freq  = ' .. ILS_freq)
    _log ('[awg] ILS name  = ' .. ILS_name)
    _log ('[awg] VOR1 crs  = ' .. VOR1_crs)
    _log ('[awg] VOR1 freq = ' .. VOR1_freq)
    _log ('[awg] VOR2 crs  = ' .. VOR2_crs)
    _log ('[awg] VOR2 freq = ' .. VOR2_freq)
    Default_DME_ILS()
end

function AB_AP_ILS1_set ()
    ipc.writeLvar("L:MCDU_ILS1_CRS", CRS1)
    _logg('[awg] ILS CRS set = ' .. CRS1)
    if _MCP1()  then
        DspShow("ILS1", CRS1)
    else
        DspCRS(CRS1)
    end
end

function AB_AP_CRS1_set ()
    ipc.writeLvar("L:MCDU_VOR1_CRS", CRS1)
    _logg('[awg] DME1 set = ' .. CRS1)
    if _MCP1()  then
        DspShow("CRS1", CRS1)
    else
        DspCRS(CRS1)
    end
end

function AB_AP_CRS2_set ()
    ipc.writeLvar("L:MCDU_VOR2_CRS", CRS2)
    _logg('[awg] DME2 CRS2 set = ' .. CRS2)
    if _MCP1()  then
        DspShow("CRS2", CRS2)
    else
        DspCRS(CRS2)
    end
end

function AB_AP_CRS_show ()
    local DME_crs
    if dme_sel then
        DME_crs = ipc.readLvar("L:MCDU_ILS1_CRS")
        _logg('[awg] ILS CRS Show = ' .. DME_crs)
    else
        DME_crs = ipc.readLvar("L:MCDU_VOR1_CRS")
        _logg('[awg] VOR1 CRS Show = ' .. DME_crs)
    end
    if DME_crs ~= -1 then
        if _MCP1()  then
            DspShow("CRS1", DME_crs)
        else
            DspCRS(DME_crs)
        end
    else
        DME_crs = 0
        if _MCP1()  then
            DspShow("CRS2", DME_crs)
        else
            DspDME(DME_crs)
        end
    end
end

function AB_AP_CRS_inc ()
    local DME_crs
    if dme_sel == 1 then
        DME_crs = RADIOS_DME_CRS1
        ipc.writeLvar("L:MCDU_ILS1_CRS", DME_crs)
        ipc.sleep(50)
        --AB_AP_CRS_show ()
    else
        DME_crs = RADIOS_DME_CRS2
        ipc.writeLvar("L:MCDU_VOR1_CRS", DME_crs)
        ipc.sleep(50)
        --AB_AP_CRS_show ()
    end
end

function AB_AP_CRS_incfast ()
    local DME_crs
    if dme_sel == 1 then
        DME_crs = RADIOS_DME_CRS1
        ipc.writeLvar("L:MCDU_ILS1_CRS", DME_crs)
        ipc.sleep(50)
        --AB_AP_CRS_show ()
    else
        DME_crs = RADIOS_DME_CRS2
        ipc.writeLvar("L:MCDU_VOR1_CRS", DME_crs)
        ipc.sleep(50)
        --AB_AP_CRS_show ()
    end
end

function AB_AP_CRS_dec ()
    local DME_crs
    if dme_sel == 1 then
        DME_crs = RADIOS_DME_CRS1
        ipc.writeLvar("L:MCDU_ILS1_CRS", DME_crs)
        ipc.sleep(50)
        --AB_AP_CRS_show ()
    else
        DME_crs = RADIOS_DME_CRS2
        ipc.writeLvar("L:MCDU_VOR1_CRS", DME_crs)
        ipc.sleep(50)
        --AB_AP_CRS_show ()
    end
end

function AB_AP_CRS_decfast ()
    local DME_crs
    if dme_sel == 1 then
        DME_crs = RADIOS_DME_CRS1
        ipc.writeLvar("L:MCDU_ILS1_CRS", DME_crs)
        ipc.sleep(50)
        --AB_AP_CRS_show ()
    else
        DME_crs = RADIOS_DME_CRS2
        ipc.writeLvar("L:MCDU_VOR1_CRS", DME_crs)
        ipc.sleep(50)
        --AB_AP_CRS_show ()
    end
end

-- ## TCAS/XPDR ###############

function AB_XPDR_Ident ()
    ipc.writeSB(0x7b93,1)
    Button3()
    DspShow("XPDR","ID")
end

function AB_XPDR_show ()
    XPDRvar = ipc.readLvar("L:Mod_Xponder_mode")
    if XPDRvar == 0 then
        XPDRtext = "off"
    elseif XPDRvar == 1 then
        XPDRtext = "stby"
    elseif XPDRvar == 2 then
        XPDRtext = "alt"
    elseif XPDRvar == 3 then
        XPDRtext = "XPDR"
    elseif XPDRvar == 4 then
        XPDRtext = "TA"
    elseif XPDRvar == 5 then
        XPDRtext = "TARA"
    end
    if _MCP1() then
        DspShow("XPDR", XPDRtext)
    elseif _MCP2() then
        DspRadioShort(XPDRtext)
    elseif _MCP2a() then
        DspShow("XPDR", XPDRtext)
    end
end

function AB_XPDR_off ()
    ipc.writeLvar("L:Mod_Xponder_mode", 1)
    ipc.writeLvar("L:Mod_Xponder_Mode_knob", 0)
    AdirsKnobRotate ()
    AB_XPDR_show ()
end

function AB_XPDR_stby ()
    ipc.writeLvar("L:Mod_Xponder_mode", 1)
    ipc.writeLvar("L:Mod_Xponder_Mode_knob", 0)
    AdirsKnobRotate ()
    AB_XPDR_show ()
end

function AB_XPDR_alt ()
    ipc.writeLvar("L:Mod_Xponder_mode", 2)
    ipc.writeLvar("L:Mod_Xponder_Mode_knob", 1)
    AdirsKnobRotate ()
    AB_XPDR_show ()
end

function AB_XPDR_xpdr ()
    ipc.writeLvar("L:Mod_Xponder_mode", 3)
    ipc.writeLvar("L:Mod_Xponder_Mode_knob", 2)
    AdirsKnobRotate ()
    AB_XPDR_show ()
end

function AB_XPDR_ta ()
    ipc.writeLvar("L:Mod_Xponder_mode", 4)
    ipc.writeLvar("L:Mod_Xponder_Mode_knob", 3)
    AdirsKnobRotate ()
    AB_XPDR_show ()
end

function AB_XPDR_tara ()
    ipc.writeLvar("L:Mod_Xponder_mode", 5)
    ipc.writeLvar("L:Mod_Xponder_Mode_knob", 4)
    AdirsKnobRotate ()
    AB_XPDR_show ()
end

-- XPDR inc

function AB_XPDR_inc ()
	i = ipc.readLvar("L:Mod_Xponder_mode")
	if i < 5 then
	   ipc.writeLvar("L:Mod_Xponder_mode", i + 1)
       ipc.writeLvar("L:Mod_Xponder_mode_knob", i)
	end
    AdirsKnobRotate ()
    AB_XPDR_show ()
end

-- XPDR dec

function AB_XPDR_dec ()
	i = ipc.readLvar("L:Mod_Xponder_mode")
 	if i > 1 then
	   ipc.writeLvar("L:Mod_Xponder_mode", i-1)
       ipc.writeLvar("L:Mod_Xponder_mode_knob", i-2)
	end
    AdirsKnobRotate ()
    AB_XPDR_show ()
end

function AB_PDS_XPNDR_abv ()
    ipc.writeLvar("L:AB_PDS_Xponder_ABW_NOR_BLW", 1)
    ASC_KnobRotate ()
    DspShow ("PDS", "abv")
end

function AB_PDS_XPNDR_nor ()
    ipc.writeLvar("L:AB_PDS_Xponder_ABW_NOR_BLW", 0)
    ASC_KnobRotate ()
    DspShow ("PDS", "nor")
end

function AB_PDS_XPNDR_blw ()
    ipc.writeLvar("L:AB_PDS_Xponder_ABW_NOR_BLW", -1)
    ASC_KnobRotate ()
    DspShow ("PDS", "blw")
end


-- ## Weather Radar ###############

function AB_WX_SYS_on ()
    ipc.writeLvar("L:AB_WX_SYS", 0)
    LightSwitch ()
    DspShow ("WXR", "on")
end

function AB_WX_SYS_off ()
    ipc.writeLvar("L:AB_WX_SYS", 1)
    LightSwitch ()
    DspShow ("WXR", "off")
end

function AB_WX_SYS_toggle ()
    if _tl("AB_WX_SYS", 1) then
        AB_WX_SYS_on ()
	else
        AB_WX_SYS_off ()
	end
end

function AB_WX_GAIN_show ()
    WXRgain = round(ipc.readLvar("L:AB_WX_GAIN")/5)
    if WXRgain == 0 then WXRgainTxt = "MIN"
    elseif WXRgain == 1 then WXRgainTxt = "-12"
    elseif WXRgain == 2 then WXRgainTxt = "-9 "
    elseif WXRgain == 3 then WXRgainTxt = "-6 "
    elseif WXRgain == 4 then WXRgainTxt = "-3 "
    elseif WXRgain == 5 then WXRgainTxt = "CAL"
    elseif WXRgain == 6 then WXRgainTxt = "+4 "
    elseif WXRgain == 7 then WXRgainTxt = "+8 "
    elseif WXRgain == 8 then WXRgainTxt = "+12"
    elseif WXRgain == 9 then WXRgainTxt = "MAX"
    end
    DspShow ("GAIN", WXRgainTxt)
end

function AB_WX_GAIN_inc ()
    WXRgain = ipc.readLvar("L:AB_WX_GAIN")
    if WXRgain < 45 then
        WXRgain = WXRgain + 5
    else
        WXRgain = 45
    end
    ipc.writeLvar("L:AB_WX_GAIN", WXRgain)
    AB_WX_GAIN_show ()
end

function AB_WX_GAIN_dec ()
    WXRgain = ipc.readLvar("L:AB_WX_GAIN")
    if WXRgain > 0 then
        WXRgain = WXRgain - 5
    else
        WXRgain = 0
    end
    ipc.writeLvar("L:AB_WX_GAIN", WXRgain)
    AB_WX_GAIN_show ()
end

function AB_WX_GAIN_cal ()
    ipc.writeLvar("L:AB_WX_GAIN", 25)
    AB_WX_GAIN_show ()
end

---

function AB_WX_TILT_show ()
    WXRTILT = ipc.readLvar("L:AB_WX_TILT")
    if WXRTILT > 97 then
        WXRTILTtxt = round((WXRTILT - 97)/2.5) + 5
    elseif WXRTILT < 30 then
        WXRTILTtxt = round (WXRTILT/2.5) - 15
    else
        WXRTILTtxt = round(((WXRTILT - 20)/7) - 5.9)
    end
    DspShow ("TILT", WXRTILTtxt)
end

function AB_WX_TILT_inc ()
    WXRTILT = ipc.readLvar("L:AB_WX_TILT")
    if WXRTILT < 122 then
        if (WXRTILT <= 25 or WXRTILT >= 97) then
            WXRTILT = WXRTILT + 5
        elseif WXRTILT >= 62 then
            WXRTILT = WXRTILT + 7
        else
            WXRTILT = WXRTILT + 8
        end
    else
        WXRTILT = 122
    end
    ipc.writeLvar("L:AB_WX_TILT", WXRTILT)
    AB_WX_TILT_show ()
    ipc.sleep(150)
end

function AB_WX_TILT_dec ()
    WXRTILT = ipc.readLvar("L:AB_WX_TILT")
    if WXRTILT > 0 then
        if (WXRTILT <= 30 or WXRTILT > 97) then
            WXRTILT = WXRTILT - 5
        elseif WXRTILT > 62 then
            WXRTILT = WXRTILT - 7
        else
            WXRTILT = WXRTILT - 8
        end
    else
        WXRTILT = 0
    end
    ipc.writeLvar("L:AB_WX_TILT", WXRTILT)
    AB_WX_TILT_show ()
    ipc.sleep(150)
end

function AB_WX_TILT_zero ()
    ipc.writeLvar("L:AB_WX_TILT", 62)
    AB_WX_TILT_show ()
    ipc.sleep(1000)
end

-----

function AB_WX_MULTI_off ()
    ipc.writeLvar("L:AB_WX_MULTI_AUTO", 0)
    LightSwitch ()
    DspShow ("MULT", "off")
end

function AB_WX_MULTI_on ()
    ipc.writeLvar("L:AB_WX_MULTI_AUTO", 1)
    LightSwitch ()
    DspShow ("MULT", "auto")
end

function AB_WX_MULTI_toggle ()
    if _tl("AB_WX_MULTI_AUTO", 0) then
        AB_WX_MULTI_on ()
	else
        AB_WX_MULTI_off ()
	end
end

-----

function AB_WX_GCS_off ()
    ipc.writeLvar("L:AB_WX_GCS", 0)
    LightSwitch ()
    DspShow ("GCS", "off")
end

function AB_WX_GCS_on ()
    ipc.writeLvar("L:AB_WX_GCS", 1)
    LightSwitch ()
    DspShow ("GCS", "auto")
end

function AB_WX_GCS_toggle ()
    if _tl("AB_WX_GCS", 0) then
        AB_WX_GCS_on ()
	else
        AB_WX_GCS_off ()
	end
end

-----

function AB_WX_TERR_on ()
    ipc.writeLvar("L:AB_MPL_ND_TERR", 1)
    LightSwitch ()
    DspShow ("TERR", "on")
end

function AB_WX_TERR_off ()
    ipc.writeLvar("L:AB_MPL_ND_TERR", 0)
    LightSwitch ()
    DspShow ("TERR", "off")
end

function AB_WX_TERR_toggle ()
    if _tl("AB_MPL_ND_TERR", 0) then
        AB_WX_TERR_on ()
	else
        AB_WX_TERR_off ()
	end
end


-- ## Other Pedestal ###############

function Spoilers_ARM ()
    ipc.control(66066)
    DspShow ("Splr", "arm")
end

function Spoilers_DISARM ()
    ipc.control(66067)
    DspShow ("Splr", "dsrm")
end

function Spoilers_arm_toggle ()
	if _tl("ASC_Spoilers_armed", 0) then
       Spoilers_ARM ()
	else
       Spoilers_DISARM ()
	end
end

function SecurityScreen_on ()
    ipc.writeLvar("L:AB_SECURITYSCREEN_SWITCH", 1)
    DspShow ("Scrn", "on")
    SmallOverheadPushButtons ()
end

function SecurityScreen_off ()
    ipc.writeLvar("L:AB_SECURITYSCREEN_SWITCH", 0)
    DspShow ("Scrn", "off")
    SmallOverheadPushButtons ()
end

function SecurityScreen_toggle ()
	if _tl("AB_SECURITYSCREEN_SWITCH", 0) then
       SecurityScreen_on ()
	else
       SecurityScreen_off ()
	end
end


-- ## windows (not OSX :) )###############

function CAPT_Window_open ()
   ipc.writeLvar("L:Sidewindow_open_CP", 1)
end

function CAPT_Window_close ()
   ipc.writeLvar("L:Sidewindow_close_CP", 1)
end

function CAPT_Window_toggle ()
	if _t("cwin") then
       CAPT_Window_open ()
	else
       CAPT_Window_close ()
	end
end

function CO_Window_open ()
   ipc.writeLvar("L:Sidewindow_open_FO", 1)
end

function CO_Window_close ()
   ipc.writeLvar("L:Sidewindow_close_FO", 1)
end

function CO_Window_toggle ()
	if _t("cowin") then
       CO_Window_open ()
	else
       CO_Window_close ()
	end
end

-- ## open doors ###############

function DOORS_Front_left_toggle ()
    ipc.control(66389)
    ipc.control(65538)
    DspShow ("Frnt", "left", "Front", "left")
end

function DOORS_Back_left_toggle ()
    ipc.control(66389)
    ipc.control(65539)
    DspShow ("Back", "left", "Back", "left")
end

function DOORS_left_toggle ()
    ipc.control(66389)
    ipc.control(65538)
    DspShow ("Frnt", "left", "Front", "left")
    ipc.sleep(1000)
    ipc.control(66389)
    ipc.control(65539)
    DspShow ("Back", "left", "Back", "left")
end

function DOORS_Front_right_open ()
    ipc.writeLvar("L:AB_Cabindoor3_target", 100)
    DspShow ("FrtR", "open", "Front R", "open")
end

function DOORS_Front_right_close ()
    ipc.writeLvar("L:AB_Cabindoor3_target", 0)
    DspShow ("FrtR", "clse", "Front R", "close")
end

function DOORS_Front_right_toggle ()
	if _tl("AB_Cabindoor3_target", 0) then
       DOORS_Front_right_open ()
	else
       DOORS_Front_right_close ()
	end
end

function DOORS_Back_right_open ()
    ipc.writeLvar("L:AB_Cabindoor4_target", 100)
    DspShow ("BckR", "open", "Back R", "open")
end

function DOORS_Back_right_close ()
    ipc.writeLvar("L:AB_Cabindoor4_target", 0)
    DspShow ("BckR", "clse", "Back R", "close")
end

function DOORS_Back_right_toggle ()
	if _tl("AB_Cabindoor4_target", 0) then
        DOORS_Back_right_open ()
	else
        DOORS_Back_right_close ()
	end
end

function DOORS_Right_open ()
    DOORS_Front_right_open ()
    ipc.sleep(500)
    DOORS_Back_right_open ()
end

function DOORS_Right_close ()
    DOORS_Front_right_close ()
    ipc.sleep(500)
    DOORS_Back_right_close ()
end

function DOORS_Right_toggle ()
	if _tl("AB_Cabindoor3_target", 0) or
        _tl("AB_Cabindoor4_target", 0)then
      DOORS_Right_open ()
	else
      DOORS_Right_close ()
	end
end

-------------

function DOORS_Cargo_front_toggle ()
    ipc.control(66389)
    ipc.control(65540)
    DspShow ("Crgo", "frnt", "Cargo", "front")
end

function DOORS_Cargo_back_toggle ()
    ipc.control(66389)
    ipc.control(65541)
    DspShow ("Crgo", "back", "Cargo", "back")
end

function DOORS_Cargo_toggle ()
    ipc.sleep(100)
    ipc.control(66389)
    ipc.sleep(100)
    ipc.control(65540)
    DspShow ("Crgo", "frnt", "Cargo", "front")
    ipc.sleep(1000)
    ipc.control(66389)
    ipc.sleep(100)
    ipc.control(65541)
    DspShow ("Crgo", "back", "Cargo", "back")
end


-- ## Ground Services ###############

function TrafficCones_set ()
    ipc.writeLvar("L:MCDU_cones", 1)
    DspShow("Cone","set")
end

function TrafficCones_removed ()
    ipc.writeLvar("L:MCDU_cones", 0)
    DspShow("Cone","rmov")
end

function TrafficCones_toggle ()
    var = ipc.readLvar("L:MCDU_cones")
    if var == 1 then
        TrafficCones_removed ()
    else
        TrafficCones_set ()
    end
end

function WheelChocks_set ()
    ipc.writeLvar("L:Wheelchocks", 1)
    DspShow("Chok","set")
end

function WheelChocks_removed ()
    ipc.writeLvar("L:Wheelchocks", 0)
    DspShow("Chok","rmov")
end

function WheelChocks_toggle ()
    var = ipc.readLvar("L:Wheelchocks")
    if var == 1 then
        WheelChocks_removed ()
    else
        WheelChocks_set ()
    end
end

function ExternalPowerGPU_conn ()
    ipc.writeLvar("L:MCDU_EXTPOWERCART", 1)
    DspShow("GPU","conn")
end

function ExternalPowerGPU_disc ()
    ipc.writeLvar("L:MCDU_EXTPOWERCART", 0)
    EXT_PWR_off ()
    DspShow("GPU","disc")
end

function ExternalPowerGPU_toggle ()
    var = ipc.readLvar("L:MCDU_EXTPOWERCART")
    if var == 1 then
        ExternalPowerGPU_disc ()
    else
        ExternalPowerGPU_conn ()
    end
end

function ExternalPower_conn ()
    ipc.writeLvar("L:MCDU_EXTPOWER", 1)
    DspShow("EPwr","conn")
end

function ExternalPower_disc ()
    ipc.writeLvar("L:MCDU_EXTPOWER", 0)
    EXT_PWR_off ()
    DspShow("EPwr","disc")
end

function ExternalPower_toggle ()
    var = ipc.readLvar("L:MCDU_EXTPOWER")
    if var == 1 then
        ExternalPower_disc ()
    else
        ExternalPower_conn ()
    end
end


-- ## other gimmicks ###############

function STBY_Compass_open ()
   ipc.writeLvar("L:AB_STDBYCompass_anim_set", 1)
end

function STBY_Compass_close ()
   ipc.writeLvar("L:AB_STDBYCompass_anim_set", 0)
end

function STBY_Compass_toggle ()
    if _tl("AB_STDBYCompass_anim_set", 0) then
       STBY_Compass_open ()
	else
       STBY_Compass_close ()
	end
end

function TableCapt_open ()
    ipc.writeLvar("L:Table1_open", 1)
end

function TableCapt_close ()
    ipc.writeLvar("L:Table1_close", 1)
end

function TableCapt_toggle ()
    if ipc.readLvar("L:Table1_pos") == 0 then
        TableCapt_open()
    else
        TableCapt_close()
    end
end

function TableFO_open ()
    ipc.writeLvar("L:Table2_open", 1)
end

function TableFO_close ()
    ipc.writeLvar("L:Table2_close", 1)
end

function TableFO_toggle ()
    if ipc.readLvar("L:Table2_pos") == 0 then
        TableFO_open()
    else
        TableFO_close()
    end
end

function Tables_close ()
    TableCapt_close()
    TableFO_close()
end

function Jumpseat_open ()
   ipc.writeLvar("L:Jumpseat_open", 1)
end

function Jumpseat_close ()
   ipc.writeLvar("L:Jumpseat_close", 1)
end

function Jumpseat_toggle ()
	if _t("jump") then
       Jumpseat_open ()
	else
       Jumpseat_close ()
	end
end


-- ## Cockpit prepare ###############
function AB_Cockpit_Prepare ()
    -- << uncomment/comment for your needs
    AB_CD ()
end

-- skip checklist item
function AB_CL_SkipItem()
   ipc.writeLvar("L:CL_Skip_Item", 1)
   DspShow("CL","skip")
end


-- ## System functions   ##

-- Initial info on MCP display
function InitDsp ()
    if _MCP1() or _MCP2() then
        DspSPD(ipc.readLvar("L:AB_AP_SPEED_Select"))
        DspHDG(ipc.readLvar("L:AB_AP_HDG_Select"))
        DspALT(ipc.readLvar("L:AB_AP_ALT_Select") / 100)
        DspVVS(ipc.readLvar("L:AB_AP_VS_Select2"))
    else -- MCP2a
        DspSPDtxt()
        DspHDGtxt()
        DspALTtxt()
        AB_DspSPD()
        AB_DspHDG()
        AB_DspALT()
        AB_DspVVS()
    end
end

-- Initial variables
function InitVars ()
    Airbus = true -- set flag for Airbus MCP2a panels
	nd_mode = 1 -- default ND mode
	baro_mode = 1  -- default BARO mode is hPa
	auto_brk = 0
    AutoDisplay = false -- override automatic display updates (SPD/HDG/ALT/VVS_
    DSP_MODE_one ()
    EcamTxt = 1
    OnVar = 16 -- change this for initial brightness of displays. 0 to 20
    --TestCnt = 0
    TestVar = ""
    TestLast = ""
    -- variables to prevent constant LCD display updating
    AB_MODE = false
    -- MCDU keyboard timeout
    AB_MCDU_KeyTimer = 60000
    AB_MCDU_KeyFlag = false
    ipc.set("MCDU", 0)
    -- ALT/VVS DspE Flash Protection
    AB_ALT_Dot = ' '
    AB_VVS_Sign = '-'
    AB_ALT_Zero = '0'
    AB_Dot = string.char(7)
    AB_NoDot = ' '
end

function AB_CD ()
    ipc.writeLvar("MCDU2_Page", 1)
    ipc.sleep(50)
    MCDU2_LSK1L ()
    ipc.sleep(50)
    ipc.writeLvar("MCDU2_Page", 0)
end

function AB_CTR_knob_show_A ()
    DspShow ("ND", "Mode")
end

function AB_CTR_knob_show_B ()
    DspShow ("WXR", "Mode")
end

function AB_TFC_knob_show_A ()
    DspShow ("ND", "Mode")
end

function AB_TFC_knob_show_B ()
    DspShow ("WXR", "Mode")
end